@@ -29,12 +29,15 @@
 #include <kconfig.h>
 #include <ksimpleconfig.h>
 
+#include <kwin.h>
+
 #include <unistd.h>  // for function sleep and other ...
 
-
-
 #include <iostream>
 
+
+
+
 //  const char *nameUpsVars1[] = {
 //  "NONE", "UTILITY", "BATTPCT", "UPSTEMP", "ACFREQ", "LOADPCT", "AMBTEMP", "AMBHUMID","BATTVOLT","OUTVOLT",CURRENT};
 //  const char *nameUpsVars2[] = {
@@ -56,21 +59,21 @@ KNutClient::KNutClient(bool noDock, QObject* parent, const char *name) : QObject
   reconnectTimer = new QTimer(this);
   connect( reconnectTimer, SIGNAL(timeout()), SLOT(slotReconnectTimeout()) );
 
-  
-  //  data pro combo
+
+  //  data for combo
   listKNutEvent = new QStringList();
-  
-  // inicializace a natazeni configurace;
+
+  // init and load of configuration
   initVars();
 
   loadConfiguration();
-  
+
   if (!noDock) {
     myDock = new KNutDock(&mainUpsInfo,&settingData,upsRecords);
-    
+
     myDock->show();
     connect(myDock, SIGNAL(endApplication()), this, SLOT(slotExitApplication()));
-    connect(myDock, SIGNAL(activeMainWindow()), this, SLOT(activeMainWindow()));
+    connect(myDock, SIGNAL(activeMainWindow()), this, SLOT(slotActiveMainWindow()));
     connect(myDock, SIGNAL(minimize()), this, SLOT(minimizeMainWindow()));
     connect(myDock, SIGNAL(UPSChanged(QString)), this, SLOT(slotSetNewUPS (QString)));
 
@@ -80,54 +83,54 @@ KNutClient::KNutClient(bool noDock, QObject* parent, const char *name) : QObject
     connect(myDock, SIGNAL(RWVars()),this, SLOT(slotRWVars()));
     connect(myDock, SIGNAL(makeRefreshConnection()),this, SLOT(slotRefreshConnection()));
     }
-  
+
   addEventString(i18n("Ready."));
 
- 
+
   // nastavime data pro vybranou polozku
   // sets data for selected item
   setActiveUpsInfo(mainUpsInfo.record.name);
 
   // sets mainUpsInfo.oldState to const value KNutNet::initStatus
   mainUpsInfo.oldState=KNutNet::initState;
-  
+
   //makes connect to UPS, connection is non blocking operation
   //we have to use signal firstConnection and connectionError from KNutNet class 
   mainUpsInfo.upsNet = new KNutNet( mainUpsInfo.record.upsAddress,mainUpsInfo.record.upsName,mainUpsInfo.record.port,5,200);
-  
+
   connect(mainUpsInfo.upsNet, SIGNAL(firstConnection(void)),this, SLOT(slotFirstConnection(void)));
   connect(mainUpsInfo.upsNet, SIGNAL(connectionError(int)),this, SLOT(slotErrorConnection(int)));
   connect(mainUpsInfo.upsNet, SIGNAL(connectionClosed(void )),this, SLOT(slotConnectionClosed(void)));
   connect(mainUpsInfo.upsNet, SIGNAL(tryFirstConnection(int )),this, SLOT(slotTryFirstConnection(int)));
   connect(mainUpsInfo.upsNet, SIGNAL(tryRepeatFirstConnection(int )),this, SLOT(slotTryReepatFirstConnection( int )));
-    
+
 
 // state of connection to usbd, this isn't state of knutnet
 //  if (mainUpsInfo.record.upsName !="") {
 //    mainUpsInfo.upsDriverState=knc::connecting;
  //   }
  // else   mainUpsInfo.upsDriverState=knc::notConnected;
-  
+
  // repaints the dock
   if (myDock) myDock->clearDockValues();
-    
+
   if (settingData.useMainWindow || noDock) makeMainWindow ();
 
   if (myDock) myMessMan = new KNutMessageManager(this);
- 
+
   //tries connecting to server
   mainUpsInfo.upsDriverState=knc::connecting;
   mainUpsInfo.upsNet->open();
   }
 
-  
+
 KNutClient::~KNutClient(void) {
 
   if (myMessMan) delete myMessMan;
 
   // melo by uz byt zruseno - jistota
   if (myDock) { myDock->close(); myDock=0l;}
-  
+
   if (mainUpsInfo.upsNet) {
   // melo by uz byt zruseno - jistota
     delete mainUpsInfo.upsNet;
@@ -144,48 +147,54 @@ KNutClient::~KNutClient(void) {
   }
 
 
-  
+
 void KNutClient::slotTryFirstConnection (int maxCount) {
+//qDebug ("KNutClient::slotTryFirstConnection");
 
- //std::cout << "--KNutClient::slotTryFirstConnection"  << std::endl;
-
-  // repaints icon 
+//knutNet begin the first test of connection (connectToHost will be made after emiting signal tryFirstConnection )
+// repaints icon 
   if (myDock) myDock->repaintDock(true);
   if (mainWindow) mainWindow->startConnectPB(maxCount);
-  }  
+  }
+
 
 void KNutClient::slotTryReepatFirstConnection (int number ) {
-
-
-  //std::cout << "--slotTryReepatFirstConnection " << number << std::endl;
+//qDebug ("KNutClient::slotTryFirstConnection");
+//knutNet begin nexts test of connection 
 
   if (mainWindow) mainWindow->setProgressConnectPB (number); 
   }
-  
-    
+
+
+
 void KNutClient::slotFirstConnection (void) {
- //std::cout << "--KNutClient::slotFirstConnection"  << std::endl;
+//qDebug ("sKNutClient::slotFirstConnection");
+//TCP - UDP connection to server was made
+
+  bool reconnecting = mainUpsInfo.reconnecting;
+
 
   mainUpsInfo.reconnecting =false;
   reconnectTimer->stop();
+
   mainUpsInfo.nutVariables = mainUpsInfo.upsNet->getNutVariables();
   mainUpsInfo.nutProtocol = mainUpsInfo.upsNet->getNutProtocol();
 
   if (mainWindow) mainWindow->hideConnectPB();
-  
-  
+
+
   // reads UPS's variables
-  int countRevision = 2; // pocet max opakovani po kterych muzeme zjistovat hodnoty
-   do {
- //std::cout << "--KNutClient::slotFirstConnection before getUpsVar calling"  << std::endl;
-    if (!(mainUpsInfo.netError = mainUpsInfo.upsNet->getUpsVars())) break;  
- //std::cout << "--KNutClient::slotFirstConnection error " << mainUpsInfo.netError  << std::endl;
-    if (mainUpsInfo.netError == KNutNet::UnknownUps) break;
-    if (mainUpsInfo.netError == KNutNet::DriverNotConnected) break;
-    countRevision--;
-    if (countRevision) sleep (2);
-    }
-  while (countRevision);
+
+    int countRevision = 2; // pocet max opakovani po kterych muzeme zjistovat hodnoty
+    do {
+      if (!(mainUpsInfo.netError = mainUpsInfo.upsNet->getUpsVars())) break;
+      if (!(mainUpsInfo.netError)) break;  // no error
+      if (mainUpsInfo.netError == KNutNet::UnknownUps) break;
+      if (mainUpsInfo.netError == KNutNet::DriverNotConnected) break;
+      countRevision--;
+      if (countRevision) sleep (2);
+      }
+    while (countRevision);
 
   if (mainUpsInfo.netError) {
     mainUpsInfo.errorUpsData=true;
@@ -194,15 +203,26 @@ void KNutClient::slotFirstConnection (void) {
       mainUpsInfo.upsDriverState=knc::notConnected;
     else
       mainUpsInfo.upsDriverState=knc::error;
+
     if (myDock) myDock->repaintDock(true);
     addEventString (KNutVarData::errorToText(mainUpsInfo.netError),mainUpsInfo.record.name);
-    KNutVarData::showError (mainUpsInfo.netError);
+//    KNutVarData::showError (mainUpsInfo.netError);
+    if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
     }
   else {
-    mainUpsInfo.upsDriverState=knc::connected;
+
+    if (reconnecting) {
+      addEventString(i18n("The connection was renewed."),mainUpsInfo.record.name);
+      if ((myMessMan) and (settingData.useMessageWindow)) myMessMan->addMessage(i18n("The connection was renewed."),knc::errorLevel,true);
+    }
+
+
+  mainUpsInfo.upsDriverState=knc::connected;
+    mainUpsInfo.errorUpsData=false;
 
     switch (mainUpsInfo.nutVariables) { // type of variables, old or new (with dot)
         case 1:
+//qDebug ("sKNutClient::slotFirstConnection - var 1");
           if (!(mainUpsInfo.upsNet->existName("BATT_RUNTIME"))) mainUpsInfo.runtimeVar="BATT_RUNTIME";
           else mainUpsInfo.runtimeVar="RUNTIME";
           mainUpsInfo.upsLoadVar="LOADPCT";
@@ -211,6 +231,7 @@ void KNutClient::slotFirstConnection (void) {
           mainUpsInfo.statusVar="STATUS";
         break;
         case 2:
+//qDebug ("sKNutClient::slotFirstConnection - var 2");
           mainUpsInfo.runtimeVar="battery.runtime";
           mainUpsInfo.upsLoadVar="ups.load";
           mainUpsInfo.lowxferVar="input.transfer.low";
@@ -218,61 +239,66 @@ void KNutClient::slotFirstConnection (void) {
           mainUpsInfo.statusVar="ups.status";
        }
 
+
     if ((settingData.useDescription) && (!mainUpsInfo.upsNet->isDescription())) mainUpsInfo.upsNet->getDescription();
       // test presunut do setActiveUpsVars
     if (mainWindow) setActiveUpsVars(true);
     else setActiveUpsVars(false);
-    
+
     // repaints main window and dock immediately
     if (mainWindow) mainWindow->showUpsData();
 //    if (myDock) myDock->repaintDock(mainUpsInfo.netError,true); // dock is repainting always
     if (myDock) myDock->repaintDock(true); // dock is repainting always
-    
+
     panelsAreZeroing=false; // analog panels isn't setting to zero
     }
-
-//std::cout << "--KNutClient::slotFirstConnection end"  << std::endl;    
-// tato cast tato cast je presunuta z konstruktoru     
   if ((mainUpsInfo.upsNet->getState() == KNutNet::Connected) && (!mainUpsInfo.errorUpsData)) {
     showStatusEvent();
     // getUpsVars loads informations about variables, but their values too
     upsTimer->start( mainUpsInfo.record.delay, TRUE ); // nastartujeme casovac - starts timer
     }
-  }  
+  }
+
 
-  
 void KNutClient::slotErrorConnection (int error) {
-//  std::cout << "--KNutClient::slotErrorConnection"  << std::endl;
+
+//qDebug ("KNutClient::slotErrorConnection (1)");
 
   if (mainWindow) mainWindow->hideConnectPB();
-    
+
   mainUpsInfo.netError = error;
   mainUpsInfo.errorUpsData=true;
   if (mainUpsInfo.netError == KNutNet::DriverNotConnected)
     mainUpsInfo.upsDriverState=knc::notConnected;
   else
     mainUpsInfo.upsDriverState=knc::error;
-  if (myDock) myDock->repaintDock(true);    
-    
+  if (myDock) myDock->repaintDock(true);
+
   if (mainUpsInfo.reconnecting) {
+//qDebug ("KNutClient::slotErrorConnection (2)");
     mainUpsInfo.reconnectCount++;
     if (mainUpsInfo.reconnectCount > countNextConnDelay) mainUpsInfo.reconnectCount = countNextConnDelay;
-    
+
     addEventString(i18n("The connection failed. The next connection will make after %1 sec.").arg(nextConnDelay[mainUpsInfo.reconnectCount-1]),mainUpsInfo.record.name);
     reconnectTimer->start( nextConnDelay[mainUpsInfo.reconnectCount-1]*1000, TRUE ); // starts reconnect timer again
     }
-  else {  
+  else {
+//qDebug ("KNutClient::slotErrorConnection (3)");
     addEventString (KNutVarData::errorToText(mainUpsInfo.netError),mainUpsInfo.record.name);
-    KNutVarData::showError (mainUpsInfo.netError);
-    }  
+//    KNutVarData::showError (mainUpsInfo.netError);
+    if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
+
+
+    }
   }
-  
-  
-    
+
+
+
 void KNutClient::initVars (void) {
 // Nasledujici data jsou nastavena pri natazeni konfigurace
-  settingData.panelFlags = KNutFrontPanel::DefaultPanelFlags; // informace v hlavnim panelu
-  settingData.toolTipFlags = KNutDock::DefaultToolTipFlags; // informace v hlavnim panelu
+//Next data is setted when konfiguration is loaded
+  settingData.panelFlags = KNutFrontPanel::DefaultPanelFlags; // informace v hlavnim panelu // information in main panel
+  settingData.toolTipFlags = KNutDock::DefaultToolTipFlags; // informace v hlavnim panelu // information in main panel
 
   mainUpsInfo.record.name="";
   mainUpsInfo.upsNet=0L;
@@ -289,7 +315,7 @@ void KNutClient::initVars (void) {
   mainUpsInfo.upsDriverState=knc::notConnected;
   mainUpsInfo.reconnectCount = 1;
   mainUpsInfo.reconnecting = false;
-  
+
   panelsAreZeroing=false;
   lastError=0; // no error
 
@@ -302,8 +328,9 @@ void KNutClient::initVars (void) {
 
   void KNutClient::loadConfiguration ( void ) {
   QString groupName;
-  upsRecord upsData; // struktura obsahuje udaje o UPS
+  upsRecord upsData; // structure includes informations about UPS // struktura obsahuje udaje o UPS
   QFont appFont = kapp->font(); // systemovy font pri startu
+  kapp->config()->setGroup ("");
   settingData.areYouSure=kapp->config()->readBoolEntry("AreYouSure",FALSE);
   settingData.useMainWindow=kapp->config()->readBoolEntry("UseMainWindow",TRUE);
   settingData.useMessageWindow=kapp->config()->readBoolEntry("UseMessageWindow",FALSE);
@@ -338,6 +365,8 @@ void KNutClient::initVars (void) {
   settingData.customKIconColor=kapp->config()->readBoolEntry("CustomKIconColor",FALSE);
   settingData.kIconBackgroundColor=kapp->config()->readColorEntry ("KIconBackGroundColor",& DEFAULT_KICON_COLOR);
   settingData.typeOfKIcon=kapp->config()->readBoolEntry("TypeOfKIcon", KNutDock::pictureKI);
+  settingData.typeDigitalProcessing=kapp->config()->readNumEntry("DigitalProcessingOfPointers", 2);
+
 
   mainUpsInfo.record.name=kapp->config()->readEntry("ActiveUps","");
 
@@ -360,9 +389,10 @@ void KNutClient::initVars (void) {
           else {
             upsData.upsAddress=upsData.upsName.mid(charPos+1);
             upsData.upsName=upsData.upsName.left(charPos);
-            }         
+            }
           }
         // zaznam existuje pokracujeme dale a nacteme zbytek hodnotet
+       // record exists, we go next and read rest of values
         upsData.delay = kapp->config()->readNumEntry("Delay",knc::DefaultDelay);
         upsData.port = kapp->config()->readNumEntry("Port",knc::DefaultPort);
 //        upsData.tcp = kapp->config()->readBoolEntry("Tcp",TRUE);
@@ -382,12 +412,13 @@ void KNutClient::initVars (void) {
 void KNutClient::saveConfiguration ( bool all ) {
   QString groupName;
   QString codeName;
-  upsRecord upsData; // struktura obsahuje udaje o UPS structure includes information about UPS
+  upsRecord upsData; // struktura obsahuje udaje o UPS // structure includes information about UPS
   int upsCount = upsRecords->getCount();
 
   kapp->config()->setGroup ("");
 
   if (all) {
+    kapp->config()->writeEntry ("DigitalProcessingOfPointers",settingData.typeDigitalProcessing);
     kapp->config()->writeEntry ("TypeOfKIcon",settingData.typeOfKIcon);
     kapp->config()->writeEntry ("KIconBackGroundColor",settingData.kIconBackgroundColor);
     kapp->config()->writeEntry ("CustomKIconColor",(settingData.customKIconColor));
@@ -468,13 +499,17 @@ bool KNutClient::commitData (QSessionManager&) {
   }
 
 
-  
+
 void KNutClient::upsActivate (void) {
 
   mainUpsInfo.upsNet = new KNutNet( mainUpsInfo.record.upsAddress,mainUpsInfo.record.upsName,mainUpsInfo.record.port,0,1);
   if (mainUpsInfo.upsNet->getState() != KNutNet::Connected) {
     mainUpsInfo.netError=mainUpsInfo.upsNet->getError(); // aktivace ups skoncila s chybou
-    KNutVarData::showError(mainUpsInfo.netError);
+//    KNutVarData::showError(mainUpsInfo.netError);
+
+    if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
+
+
     mainUpsInfo.errorUpsData=true;
     mainUpsInfo.upsDriverState=knc::notConnected;
     }
@@ -493,10 +528,13 @@ void KNutClient::upsActivate (void) {
       if (countRevision) sleep (2);
       }
     while (countRevision);
-    
+
     if (mainUpsInfo.netError) {
        addEventString (KNutVarData::errorToText(mainUpsInfo.netError),mainUpsInfo.record.name);
-       KNutVarData::showError (mainUpsInfo.netError);
+//       KNutVarData::showError (mainUpsInfo.netError);
+
+    if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
+
        mainUpsInfo.errorUpsData=true;
        if (mainUpsInfo.netError == KNutNet::DriverNotConnected)
          mainUpsInfo.upsDriverState=knc::notConnected;
@@ -542,7 +580,7 @@ void KNutClient::upsDeactivate (void) {
   mainUpsInfo.netError=0; // no error
   mainUpsInfo.nutVariables=0;
 //  upsDeactivateMutex.unlock();
-  } 
+  }
 
 void KNutClient::setActiveUpsVars (bool mWindow) {
   // nastavujeme jen pokud existuji nejake promene
@@ -571,7 +609,7 @@ void KNutClient::setActiveUpsVars (bool mWindow) {
     setActiveXFerVars(true);
     }
   }
-  
+
 
 void KNutClient::setActiveXFerVars (bool activate) {
   if (activate) {
@@ -589,7 +627,7 @@ void KNutClient::setActiveXFerVars (bool activate) {
 void KNutClient::setActiveUpsInfo (QString name) {
   //presuneme jmena  z databaze ups-ek - je nahrana z config. souboru
   upsRecord* upsRecordPointer;
-  
+
   if ((!name.isNull()) && (!name.isEmpty()) && ((upsRecordPointer = upsRecords->findName(name)) != 0L)) {
 
     mainUpsInfo.record.upsName = upsRecordPointer->upsName;
@@ -603,13 +641,15 @@ void KNutClient::setActiveUpsInfo (QString name) {
     int ii = 0;
     for (int i =0; i < knc::NumberOfVars; i++)
       if (upsRecordPointer->upsVarCode[i]>0) mainUpsInfo.record.upsVarCode[ii++] = upsRecordPointer->upsVarCode[i];
-    }       
+    }
   }
 
 
 void KNutClient::getUpsData (void) {
   int runNetError;
 
+//qDebug("KNutClient::getUpsData");
+
   //loads values for selected variables <getUpsValues(false)>  / activate values
   if (!(runNetError=mainUpsInfo.upsNet->getUpsValues(false))) { // data from upsNet is ok
     // we read all values of UPS
@@ -635,7 +675,7 @@ void KNutClient::getUpsData (void) {
         if ((myMessMan) and (settingData.useMessageWindow)) myMessMan->addMessage(KNutVarData::errorToText(runNetError),knc::errorLevel);
         lastError=runNetError;
         }
-      }    
+      }
     }
   }
 
@@ -653,7 +693,7 @@ void KNutClient::addEventString (const QString text, const QString UPSAddress) {
       if (listKNutEvent->count() > knc::maxCountKNutEvent) listKNutEvent->remove(listKNutEvent->begin());
       }
     }  
-  
+
 /*********************************************************************************************/
 /*                                                                                           */
 /*                             PRIVATE SLOTS                                                 */
@@ -662,7 +702,6 @@ void KNutClient::addEventString (const QString text, const QString UPSAddress) {
 
 
 void KNutClient::slotReconnectTimeout (void) {
-//  std::cout << "KNutClient::ReconnectTimeout" << std::endl;  
 
     mainUpsInfo.netError=0; //clears netError
     mainUpsInfo.upsDriverState=knc::connecting;
@@ -670,9 +709,9 @@ void KNutClient::slotReconnectTimeout (void) {
   }
 
 
-  
+
 void KNutClient::slotTimeout (void) {
-  
+
   getUpsData();
   if (!mainUpsInfo.errorUpsData) { // no error
     if (mainWindow) {
@@ -686,22 +725,22 @@ void KNutClient::slotTimeout (void) {
     if ((mainWindow) && (!panelsAreZeroing)) mainWindow->zeroingPanels();
     panelsAreZeroing=true;
     if (myDock) myDock->clearDockValues();
-    }    
+    }
   if (myDock) myDock->repaintDock();
   upsTimer->start( mainUpsInfo.record.delay, TRUE ); // nastartujem znovu
   }
 
 
 void KNutClient::slotConnectionClosed(void) {
+//qDebug("KNutClient::slotConnectionClosed");
 
   mainUpsInfo.netError = KNutNet::ConnetionClosedByServer;
 
-//  std::cout << "-----KNutClient::slotConnectionClosed----" << std::endl;  
   upsTimer->stop();
   upsDeactivate();
   //sets netError this, because procedure upsDeactivate sets netError to zero
   mainUpsInfo.netError = KNutNet::ConnetionClosedByServer;
-  
+
   if (mainWindow) {
     mainWindow->hideConnectPB();
     mainWindow->cleanPanels();    
@@ -710,20 +749,22 @@ void KNutClient::slotConnectionClosed(void) {
     // clears values of dock and set standard icon of dock
    myDock->clearDockValues();
    }
-  
+
   addEventString(i18n("The connection was closed by the second side (upsd)."),mainUpsInfo.record.name);
-  if ((myMessMan) and (settingData.useMessageWindow)) myMessMan->addMessage(i18n("The connection was closed by the second side (upsd)."),knc::criticalLevel,true);
+  if ((myMessMan) and (settingData.useMessageWindow)) myMessMan->addMessage(i18n("The connection was closed by the second side (upsd)."),knc::errorLevel,true);
 
   mainUpsInfo.reconnecting = true;
   mainUpsInfo.reconnectCount = 1;
   reconnectTimer->start( nextConnDelay[0]*1000, TRUE ); // start timer for reconnect delay
-  }  
-  
+  }
+
 void KNutClient::showStatusEvent(void) {
 
+
+//qDebug ("KNutClient::showStatusEvent");
   int myState = mainUpsInfo.upsNet->readStatus();
   if (myState != mainUpsInfo.oldState) {
-  
+
     if ((myState & KNutNet::OFF) != (mainUpsInfo.oldState & KNutNet::OFF)) {
       if (myState & KNutNet::OFF) {
         addEventString(i18n("UPS is off."),mainUpsInfo.record.name);
@@ -805,7 +846,7 @@ void KNutClient::showStatusEvent(void) {
     mainUpsInfo.oldState=myState;
     }
   }
-  
+
 void KNutClient::slotSetNewUPS (QString name) {
 
   mainUpsInfo.reconnecting =false;
@@ -814,7 +855,7 @@ void KNutClient::slotSetNewUPS (QString name) {
   if (name  != mainUpsInfo.record.name) {
     upsTimer->stop();
     upsDeactivate(); 
-    
+
     addEventString(i18n("Switched"),name);
     if (myMessMan) myMessMan->deleteMessage();
 
@@ -822,32 +863,36 @@ void KNutClient::slotSetNewUPS (QString name) {
     mainUpsInfo.errorUpsData=false;
     setActiveUpsInfo(mainUpsInfo.record.name);
 
+    //new connection name and password are cleaned
+    mainUpsInfo.name = "";
+    mainUpsInfo.password = "";
+
     if (mainWindow) {
       mainWindow->setCombo(name);
 //      mainWindow->showUpsData();
-      mainWindow->cleanPanels();    
+      mainWindow->cleanPanels();
       }
-   
+
    if (myDock) {
       // clears values of dock and set standard icon of dock
      myDock->clearDockValues();
      myDock->setNewUPS(); // sets miniIcon in list of UPSes for selected UPS
      }
-    
+
     panelsAreZeroing=false;
     lastError=0; // zadna chyba
     mainUpsInfo.oldState=KNutNet::initState; // init variable of last UPS state
-    
+
     // nova cast
-    
+
     mainUpsInfo.upsNet->newUPS(mainUpsInfo.record.upsAddress,mainUpsInfo.record.upsName, mainUpsInfo.record.port);
      // state of connection to usbd, this isn't state of knutnet
     mainUpsInfo.upsDriverState=knc::connecting;
     mainUpsInfo.upsNet->open();
-    }  
+    }
   }
 
-  
+
 void KNutClient::slotPreferenceUps (void) {
 
   KNutPrefDlg* prefDlg = new KNutPrefDlg ( upsRecords, analogRecords, &settingData, mainUpsInfo.record.name ); // aktivujeme dialog pro preference
@@ -860,7 +905,7 @@ void KNutClient::slotPreferenceUps (void) {
 void KNutClient::slotSetConfig (unsigned int changeSetting) {
 
   if (changeSetting) {
-    // cely blok konfiguraci ukladame jen zde
+    // cely blok konfiguraci ukladame jen zde // all block of cobfigurations is saved only here
     saveConfiguration(true);
     if (changeSetting & KNutPrefDlg::ChangeXFer) {
       if (settingData.lowHighXfer)
@@ -911,7 +956,7 @@ void KNutClient::slotSetConfig (unsigned int changeSetting) {
 //        upsTimer->start( mainUpsInfo.record.delay, TRUE ); // nastartujeme casovac
 //        }
       }
-    
+
     if (changeSetting & KNutPrefDlg::ChangeUpsCount) {
       if (myDock) myDock->changeUps();
       }
@@ -931,7 +976,8 @@ void KNutClient::slotSetConfig (unsigned int changeSetting) {
     if (changeSetting & KNutPrefDlg::ChangeToolTip) {
       if (myDock) myDock->changeToolTip();
       }
-                
+
+    //for other settings will call functions from mainWindow class
     if (mainWindow) mainWindow->setConfig (changeSetting);
     }
   }
@@ -946,8 +992,15 @@ void KNutClient::slotPrintUPSVars(void) {
         if (windowUpsVars->upsOk()) windowUpsVars->exec();
         delete windowUpsVars;
         }
-      } else KNutVarData::showError (mainUpsInfo.netError);
-    } else KNutVarData::showError (KNutNet::NotConnection);
+      } else {
+        //  KNutVarData::showError (mainUpsInfo.netError);
+          if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
+      }
+    } else {
+      //  KNutVarData::showError (KNutNet::NotConnection);
+        if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(KNutNet::NotConnection),knc::errorLevel,true);
+
+       }
   }
 
 
@@ -960,8 +1013,16 @@ void KNutClient::slotInstComms(void) {
         if (windowInstComms->upsOk()) windowInstComms->exec();
         delete windowInstComms;
         }
-      } else KNutVarData::showError (mainUpsInfo.netError);
-    } else KNutVarData::showError (KNutNet::NotConnection);  
+      }
+    else { 
+//      KNutVarData::showError (mainUpsInfo.netError);
+      if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
+      }
+    }
+  else {
+//    KNutVarData::showError (KNutNet::NotConnection);
+    if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(KNutNet::NotConnection),knc::errorLevel,true);
+    }
   }
 
 void KNutClient::slotRWVars(void) {
@@ -974,36 +1035,49 @@ void KNutClient::slotRWVars(void) {
         if (windowRWVars->upsOk())  windowRWVars->exec();
         delete windowRWVars;
        }
-     }  else KNutVarData::showError (mainUpsInfo.netError);
-    } else KNutVarData::showError (KNutNet::NotConnection);  
+     }
+   else {
+    // KNutVarData::showError (mainUpsInfo.netError);
+     if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(mainUpsInfo.netError),knc::errorLevel,true);
+      }
+    }
+  else {
+   // KNutVarData::showError (mainUpsInfo.netError);
+    if ((myMessMan)) myMessMan->addMessage(KNutVarData::errorToText(KNutNet::NotConnection),knc::errorLevel,true);
+    }
   }
 
 
 void KNutClient::slotRefreshConnection(void) {
 
-    reconnectMutex.lock();
-    
-    mainUpsInfo.reconnecting =false;
-    reconnectTimer->stop();
-    upsTimer->stop();
-    upsDeactivate(); // closes connections
-    
+  reconnectMutex.lock();
+
+  mainUpsInfo.reconnecting =false;
+  reconnectTimer->stop();
+  upsTimer->stop();
+  upsDeactivate(); // closes connections
+
     // nastavime na docku iconu
     // sets icon for dock
-    if (myDock) {
-      myDock->clearDockValues();
+  if (myDock) {
+    myDock->clearDockValues();
  //     myDock->initImage();
  //     myDock->repaint();
-      }
-    if (mainWindow) {
-      mainWindow->cleanPanels();
-      }
-    addEventString(i18n("Reconnect"),mainUpsInfo.record.name);
-    if (myMessMan) myMessMan->deleteMessage();
+    }
+  if (mainWindow) {
+    mainWindow->cleanPanels();
+    }
+  addEventString(i18n("Reconnect"),mainUpsInfo.record.name);
+  if (myMessMan) myMessMan->deleteMessage();
 
 //    mainUpsInfo.record.name=name;
-    mainUpsInfo.errorUpsData=false;
-    setActiveUpsInfo(mainUpsInfo.record.name);
+  mainUpsInfo.errorUpsData=false;
+  setActiveUpsInfo(mainUpsInfo.record.name);
+
+  //new connection name and password are cleaned
+  mainUpsInfo.name = "";
+  mainUpsInfo.password = "";
+
 
   panelsAreZeroing=false;
   lastError=0; // zadna chyba
@@ -1015,15 +1089,15 @@ void KNutClient::slotRefreshConnection(void) {
   mainUpsInfo.upsNet->open();
   reconnectMutex.unlock();
   }
-                
+
 
 void KNutClient::slotChangeRWVars( QString ) {
   // informace ze doslo k uspesne zmene promene
   // vzhledem k asynchronimu zpracovani muze upsd vratit tuto hodnotu az za nejakou dobu
   // nevim zda bude potreba
   }
-      
-            
+
+
 void KNutClient::exitMainWindow (void) {
 
   mainWindow=0;
@@ -1054,15 +1128,18 @@ void KNutClient::makeMainWindow (void) {
   connect(mainWindow, SIGNAL(endApplication()), this, SLOT(slotExitApplication()));
   connect(mainWindow, SIGNAL(destroyed()), this, SLOT(exitMainWindow()));
   }
-  
-void KNutClient::activeMainWindow (void) {
+
+
+
+void KNutClient::slotActiveMainWindow (void) {
+
   if (!mainWindow) {
     //  pred activaci nastaveme promenne znovu precteme data
     // state of connection to usbd, this isn't state of knutnet
     if (mainUpsInfo.upsDriverState==knc::connected) {
       upsTimer->stop();
       setActiveUpsVars(true);
-      getUpsData(); 
+      getUpsData();
       makeMainWindow();
       if (myDock) myDock->repaintDock(mainUpsInfo.netError);
       upsTimer->start( 1, TRUE ); // nastartujem znovu
@@ -1076,8 +1153,13 @@ void KNutClient::activeMainWindow (void) {
       if (!mainUpsInfo.errorUpsData) {
         if (myDock) myDock->repaintDock(mainUpsInfo.netError);
         }
-      }  
-    } // end if mainWindow
+      }
+    }
+  else {   // end if mainWindow
+    //activates main window
+    mainWindow->raise();
+    KWin::activateWindow(mainWindow->winId());
+    }
   }
 
 void KNutClient::minimizeMainWindow (void) {
@@ -1091,7 +1173,6 @@ void KNutClient::minimizeMainWindow (void) {
   }
 
 
-  
 void KNutClient::slotExitApplication(void) {
 
   upsTimer->stop();
