@@ -28,6 +28,7 @@
 #include <qpainter.h>
 #include <qtooltip.h>
 #include <qpixmap.h>
+#include <qbitmap.h>
 #include <qstring.h>
 
 
@@ -39,148 +40,45 @@
 
 KNutDock::KNutDock(struct upsInfo* tActiveUpsInfo, SettingDataDef* tSettingData, KNutUpsData* tUpsRecords){
   QString valueName;
-//  bool okFloat;
 
   m_settingData = tSettingData;
   m_upsRecords = tUpsRecords;
   m_activeUpsInfo = tActiveUpsInfo;
 
-//  oldNetError = 0;
-
 //saves backgroundcolor of kicker  
   backgroundColor = paletteBackgroundColor();
 
   m_typeOfIcon = m_settingData->typeOfKIcon;
 
-//  if (!m_settingData->customKIconColor) m_myBGColor = Qt::white;
   if (!m_settingData->customKIconColor) m_myBGColor = backgroundColor;
   else m_myBGColor = m_settingData->kIconBackgroundColor;
 
   m_toolTipFlags=m_settingData->toolTipFlags;
 
-    
-//  dataOk = false; // dataOk spojeni nebylo navazano
-//  nemazat pro informaci
+  clearValues();
 
-//  batteryChargeValue = 0;
-//  runtimeValue = 0;
-//  upsLoadValue = 0;
-//  statusValue = 0;
 
-   clearValues();
-  
-        
   KIconLoader *loader = KGlobal::iconLoader();
   m_mainPix = loader->loadIcon ("knutclient",KIcon::Small,16);
-  
+
   // aplications's own icons
   m_errorPix = UserIcon ("knc_error");
   m_connectPix = UserIcon ("knc_conn");
-  
-  
-  //initImage();
-  
+  m_upsPix = UserIcon ("knc_ups");
+  m_battPix = UserIcon ("knc_batt");
 
   createMainMenu();
 
-  m_statusLayer = 0L;
-  m_runtimeLayer = 0L;
-  m_batteryLayer = 0L;
-  m_upsLayer = 0L;
-  
-  
- // if (typeOfIcon == knc::generalKI) {
- //   statusLayer = new QPixmap(24,24);
- //   runtimeLayer = new QPixmap(24,24);
- //   }
- // else {
- //   batteryLayer = new QPixmap(24,24);
- //   upsLayer = new QPixmap(24,24);
- //   }
-    
+  m_statusLayer = 0;
+  m_runtimeLayer = 0;
+
   m_loadLayer = new QPixmap(24,24);
   m_chargeLayer = new QPixmap(24,24);
-  m_mainLayer = new QPixmap(24,24); 
+  m_mainLayer = new QPixmap(24,24);
 
-    
-//  if (activeUpsInfo->upsNet != 0) {
-//    QString nutStringVar;
 
-//    if (!activeUpsInfo->upsNet->existName(activeUpsInfo->runtimeVar)) {
-//      nutStringVar = activeUpsInfo->upsNet->readStringVar(activeUpsInfo->runtimeVar);
-//      if (nutStringVar.isEmpty()) runtimeValue = knc::numberVarError;
-//      else {
-//        runtimeValue = (int)nutStringVar.toFloat(&okFloat);
-//        if (!okFloat) runtimeValue=knc::numberVarError;
-//        }
-//      }
-//    else runtimeValue=knc::numberVarError;
-
-//    if (activeUpsInfo->nutVariables == 1) valueName = "BATTPCT";
-//    else valueName = "battery.charge";
-//    if (!activeUpsInfo->upsNet->existName(valueName)) {
-//      nutStringVar = activeUpsInfo->upsNet->readStringVar(valueName);
-//      if (nutStringVar.isEmpty()) batteryChargeValue=knc::numberVarError;
-//      else {
-//        batteryChargeValue = (int)nutStringVar.toFloat(&okFloat);
-//        if (!okFloat) batteryChargeValue=knc::numberVarError;
-//        }
-//      }
-//    else batteryChargeValue=knc::numberVarError;
-    
-
-//    if (activeUpsInfo->nutVariables == 1) valueName = "LOADPCT";
-//    else valueName = "ups.load";
-//    if (!activeUpsInfo->upsNet->existName(valueName)) {
- //     nutStringVar = activeUpsInfo->upsNet->readStringVar(valueName);
-//      if (nutStringVar.isEmpty()) upsLoadValue=knc::numberVarError;
-//      else {
-//        upsLoadValue = (int)nutStringVar.toFloat(&okFloat);
-//        if (!okFloat) upsLoadValue=knc::numberVarError;
-//        }
-//      }
-//    else upsLoadValue=knc::numberVarError;
-    
-//    statusValue = (activeUpsInfo->upsNet->readStatus());
-//    statusBatValue =  statusValue & KNutNet::OB;  
-
-  // statusWarningValue = statusValue & (KNutNet::CAL | KNutNet::TRIM | KNutNet::BOOST
-  //                       | KNutNet::OVER  | KNutNet::RB);
- //   }
-
-  m_mainLayer->fill(m_myBGColor);
-//  if (typeOfIcon == knc::generalKI) {
-    
-//    paintStatus (statusValue);
-//   paintLoad(upsLoadValue);
-//    paintRuntime (runtimeValue, statusValue);
-//    paintCharge (runtimeValue);
-
-//    bitBlt (mainLayer,0,0,statusLayer,0,0,24,24,AndROP);
-//    bitBlt (mainLayer,0,0,loadLayer,0,0,24,24,AndROP);
-//    bitBlt (mainLayer,0,0,runtimeLayer,0,0,24,24,AndROP);
-//    bitBlt (mainLayer,0,0,chargeLayer,0,0,24,24,AndROP);
-  //  }
-//  else { // paints icon
-    // paints background for battery and UPS
- //   paintBattery();
- //   paintUps();
-    // adds devides for OL and OB
-// pridata rozdeleni pro OL a OB
-
- //   if (statusValue & KNutNet::OL) bitBlt (mainLayer,0,0,loadLayer,0,0,24,24,AndROP);
- //   else bitBlt (mainLayer,0,0,chargeLayer,0,0,24,24,AndROP);
- //   if (!statusWarningValue) paintOKPoint();
- //   else paintErrorPoint();
-//    }
-    
-
-    
   initImage();
   changeKIcon(); // this function calls function repaintIcon 
-  
-//  toolTip(runtimeValue, statusValue, batteryChargeValue, upsLoadValue);
-//  repaint();
 
   }
 
@@ -189,8 +87,6 @@ KNutDock::~KNutDock(){
 
   if (m_statusLayer) delete m_statusLayer;
   if (m_runtimeLayer) delete m_runtimeLayer;
-  if (m_upsLayer) delete m_upsLayer;
-  if (m_batteryLayer) delete m_batteryLayer;
 
   delete m_loadLayer;
   delete m_chargeLayer;
@@ -212,37 +108,35 @@ void KNutDock::clearDockValues(void){
   initImage(); // paints standart icon
 
   clearValues();
-  
-//  batteryChargeValue = 0;
-//  runtimeValue = 0;
-//  upsLoadValue = 0;
-//  statusValue = 0;
-  
   repaintDock(true);
   }
-  
-  
+
+
 void KNutDock::changeToolTip(void){
 
   m_toolTipFlags=m_settingData->toolTipFlags;
   toolTip(m_runtimeValue, m_statusValue, m_batteryChargeValue, m_upsLoadValue);
   }
 
-  
+
 void KNutDock::changeKIBColor(void) {
 
-  // if customKIconColor is true use our own color
-  //if (!m_settingData->customKIconColor) m_myBGColor = Qt::white; // uses standard background color
   if (!m_settingData->customKIconColor) m_myBGColor = backgroundColor;
   else m_myBGColor = m_settingData->kIconBackgroundColor; // uses defined color
-    
+
   repaintDock(true);
   }
-  
+
 void KNutDock::changeKIcon (void) {
 
   m_typeOfIcon = m_settingData->typeOfKIcon;
   if ( m_typeOfIcon == generalKI) {
+
+    if (m_mainLayer) {
+    delete m_mainLayer;
+    m_mainLayer=new QPixmap(24,24);
+    }
+
     if (!m_statusLayer) {
       m_statusLayer = new QPixmap(24,24);
       }
@@ -251,33 +145,20 @@ void KNutDock::changeKIcon (void) {
       }
     paintStatus(m_statusValue);
     paintRuntime(m_runtimeValue, m_statusValue);
-    delete m_upsLayer;
-    m_upsLayer = 0L;
-    delete m_batteryLayer;
-    m_batteryLayer=0L;
     }
-  else {
-    if (!m_batteryLayer) {
-      m_batteryLayer = new QPixmap(24,24);
-      paintBattery();
-      }
-    if (!m_upsLayer) {
-      m_upsLayer = new QPixmap(24,24);
-      paintUps();
-      }
+  else {  // picture Icon
     delete m_statusLayer;
-    m_statusLayer = 0L;
+    m_statusLayer = 0;
     delete m_runtimeLayer;
-    m_runtimeLayer=0L;
-    }        
+    m_runtimeLayer=0;
+    }
   paintLoad(m_upsLoadValue);
   paintCharge(m_batteryChargeValue);
 
   m_statusWarningValue = m_statusValue & (KNutNet::CAL | KNutNet::TRIM | KNutNet::BOOST
                      | KNutNet::OVER | KNutNet::RB);
   repaintDock(true);
-//  repaintDock(oldNetError,true);
-  }  
+  }
 
 void KNutDock::initImage(void) {
   setPixmap(m_mainPix);
@@ -290,7 +171,7 @@ void KNutDock::setNewUPS(void) {
   createUpsMenu();
   }
 
-  
+
 void KNutDock::repaintDock (const bool always) {
   QString nutStringVar;
   int myRuntimeValue;
@@ -302,7 +183,9 @@ void KNutDock::repaintDock (const bool always) {
   // value repaintNow is seted when some ups values are changed
   bool okFloat;
   QString valueName;
-        
+  QPainter paint;
+
+
   if (m_activeUpsInfo->upsNet == 0) { repaint(); return;}
 
   m_dataOkOld=m_dataOk; 
@@ -311,7 +194,7 @@ void KNutDock::repaintDock (const bool always) {
        && (!m_activeUpsInfo->netError))  {
     // ups is connected dataOK is ok (program shows icon of connecting UPS)
     m_dataOk = ok; // pro paint event udava ze mam pouzit nase ikony
-    
+
     if (!m_activeUpsInfo->upsNet->existName(m_activeUpsInfo->runtimeVar)) {
       nutStringVar = m_activeUpsInfo->upsNet->readStringVar(m_activeUpsInfo->runtimeVar);
 //std::cout << "KNutDock::repaintDock RUNTIME " << nutStringVar << std::endl;
@@ -324,18 +207,17 @@ void KNutDock::repaintDock (const bool always) {
     else myRuntimeValue = knc::numberVarError;
 
     myStatusValue = m_activeUpsInfo->upsNet->readStatus();
-    
-        
+
+
     switch (m_typeOfIcon) {
       case generalKI:
 //    *********STATUS****************  
-//      myStatusValue = activeUpsInfo->upsNet->readStatus();
       if (myStatusValue !=m_statusValue  ) {
         m_statusValue = myStatusValue;
         paintStatus(m_statusValue);
         repaintNow = true;
         }
-        
+
 //   **********RUNTIME***********
       myStatusBatValue = myStatusValue & KNutNet::OB; // OB = UPS runs on battery 
       if ((myRuntimeValue != m_runtimeValue) || (myStatusBatValue != m_statusBatValue)) {
@@ -347,10 +229,9 @@ void KNutDock::repaintDock (const bool always) {
         repaintNow = true;
         }
       break;
-      
+
       case pictureKI:
 //    *********STATUS****************
-//      myStatusValue = activeUpsInfo->upsNet->readStatus();
       if (myStatusValue !=m_statusValue  ) {
         m_statusValue = myStatusValue;
         m_statusWarningValue = myStatusValue & (KNutNet::CAL | KNutNet::TRIM | KNutNet::BOOST
@@ -364,7 +245,7 @@ void KNutDock::repaintDock (const bool always) {
         repaintNow = true;
         }
       break;
-      }
+      } /////////////////////  end of models
 
     // Other values are for all modes
 
@@ -383,11 +264,11 @@ void KNutDock::repaintDock (const bool always) {
 
     if (myUpsLoadValue != m_upsLoadValue) {
       m_upsLoadValue = myUpsLoadValue;
-      paintLoad(m_upsLoadValue);
+      if (m_typeOfIcon == generalKI) paintLoad(m_upsLoadValue);
       repaintNow = true;
       }
 
-//  *********BATTERY CHARGE****************      
+//  *********BATTERY CHARGE****************
     if (m_activeUpsInfo->nutVariables == 1) valueName="BATTPCT";
     else valueName="battery.charge";
     if (!m_activeUpsInfo->upsNet->existName(valueName)) {
@@ -402,35 +283,81 @@ void KNutDock::repaintDock (const bool always) {
 
     if (myBatteryChargeValue != m_batteryChargeValue) {
       m_batteryChargeValue = myBatteryChargeValue;
-      paintCharge(m_batteryChargeValue);
+      if (m_typeOfIcon == generalKI)paintCharge(m_batteryChargeValue);
       repaintNow = true;
       }
 //  ************* End of values********************
 
     if (repaintNow || always  || (m_dataOk != m_dataOkOld)) {
-      m_mainLayer->fill(m_myBGColor);
-//      if (typeOfIcon == knc::generalKI) {
+
+
       switch (m_typeOfIcon) {
         case generalKI:
+          m_mainLayer->fill(m_myBGColor);
+//          copyBlt (m_mainLayer,0,0,m_runtimeLayer,0,0,24,24);
           bitBlt (m_mainLayer,0,0,m_runtimeLayer,0,0,24,24,AndROP);
           bitBlt (m_mainLayer,0,0,m_loadLayer,0,0,24,24,AndROP);
           bitBlt (m_mainLayer,0,0,m_chargeLayer,0,0,24,24,AndROP);
           bitBlt (m_mainLayer,0,0,m_statusLayer,0,0,24,24,AndROP);
         break;
-    //    }
-//      else {
         case pictureKI:
-          if (m_statusValue & KNutNet::OL) bitBlt (m_mainLayer,0,0,m_loadLayer,0,0,24,24,AndROP); // icon of UPS
-          else bitBlt (m_mainLayer,0,0,m_chargeLayer,0,0,24,24,AndROP); // icon of battery
-          if (!m_statusWarningValue) paintOKPoint();
-          else paintErrorPoint();
+//          if (m_statusValue & KNutNet::OL) bitBlt (m_mainLayer,0,0,m_loadLayer,0,0,24,24,AndROP); // icon of UPS
+          if (m_statusValue & KNutNet::OL) {  // ONLINE - icon of UPS
+            int myLoad;
+            QPainter paint;
+            copyBlt (m_mainLayer,0,0,&m_upsPix,0,0,24,24); // icon of UPS
+
+            paint.begin(m_mainLayer);
+            if (m_upsLoadValue == knc::numberVarError) myLoad=0;
+            else myLoad = abs(m_upsLoadValue/10);
+
+            if (m_upsLoadValue != knc::numberVarError) {
+            if (myLoad > 12) myLoad=12;
+            if (myLoad > 10) myLoad++; // preskocime rysku pro 100 %
+            if (myLoad < 9) paint.setPen(QColor(0,192,0)); //green
+            else {
+              if (myLoad < 11) paint.setPen(QColor(255,255,0)); //yellow
+              else paint.setPen(QColor(255,0,0));//red
+              }
+            for (int i = 19; i < 22; i++) paint.drawLine(i,13,i,13-myLoad +1);
+
+            if (myLoad < 13) {
+              paint.setPen(QColor(168,220,255));
+                for (int i = 20; i < 23; i++ ) paint.drawLine(i,1,i,13-myLoad);
+                }
+              }
+            paint.setPen(QColor(Qt::black)); // line for 100 % load
+            paint.drawLine(19,3,22,3);
+            if (!m_statusWarningValue) paintOKPoint(paint);
+            else paintErrorPoint(paint);
+            paint.end();
+            }
+          else {
+            QPainter paint;
+            copyBlt (m_mainLayer,0,0,&m_battPix,0,0,24,24); // icon of Battery
+            paint.begin(m_mainLayer);
+            if (m_batteryChargeValue != knc::numberVarError) {
+              if (m_batteryChargeValue < 40) paint.setPen(Qt::red);
+              else paint.setPen(Qt::black);
+              if (m_batteryChargeValue < 40) paint.setPen(Qt::red);
+              else {
+                if (m_batteryChargeValue < 50) paint.setPen(Qt::yellow);
+                else paint.setPen(Qt::green);
+                }
+              int delka = abs((16*m_batteryChargeValue)/100);
+              delka += abs((delka-1)/4) -1;
+              paint.drawLine (2,7,2+delka,7);
+              paint.drawLine (2,8,2+delka,8);
+              paint.drawLine (2,9,2+delka,9);
+              }
+            paint.end();
+            }
         break;
         }
       toolTip(m_runtimeValue, m_statusValue, m_batteryChargeValue, m_upsLoadValue);
-      setPixmap(*m_mainLayer);                
+
+      setPixmap(*m_mainLayer);
       }
-//    setPixmap(*mainLayer);                
-//    toolTip(runtimeValue, statusValue, batteryChargeValue, upsLoadValue);
     }
   else { // KNutNet->state isn't  connected
      // we must test activeUpsInfo->netError because error can rise higher level
@@ -448,14 +375,16 @@ void KNutDock::repaintDock (const bool always) {
       if (m_dataOk == connecting) setPixmap(m_connectPix);
       else {
         if (m_dataOk == error) setPixmap(m_errorPix);
-        else  setPixmap(m_mainPix);
+        else  {
+          setPixmap(m_mainPix);
+          }
         }
       }
     }
-  repaint();      
+  repaint();
   }
-  
-  
+
+
 
 void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad ) {
 
@@ -486,7 +415,7 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
       break;
       }
     }
-    
+
   text = i18n("Name")+" : "+m_activeUpsInfo->record.name + "\n"
   +i18n("UPS name")+" : "+m_activeUpsInfo->record.upsName + "\n"
   +i18n("UPS address")+" : "+m_activeUpsInfo->record.upsAddress +"\n"
@@ -509,7 +438,7 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
           }
         }  
       }
-    
+
     if (status & KNutNet::LB) {
       text += "\n" + i18n("Status : ") + i18n("UPS Battery is low");
       }
@@ -534,7 +463,7 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
   if ((status == -1) && (myNetErr != KNutNet::NoError)) {
     text += "\n" + i18n("Error : ")+ KNutVarData::errorToText(myNetErr);
     }
-  
+
   if (m_toolTipFlags & TTMFR) text += "\n" + i18n("Manufac. : ")+ manufacturer;
 
   if (m_toolTipFlags & TTModel) text += "\n" + i18n("Name")+" : "+ upsModel;
@@ -542,26 +471,20 @@ void KNutDock::toolTip (int runtime, int status, int batteryCharge, int upsLoad
   if (m_toolTipFlags & TTSerial) text += "\n" + i18n("Serial")+" : "+ serial;
 
   if (m_toolTipFlags & TTFirm) text += "\n" + i18n("Firmware")+" : "+ firmware;
-      
+
   if (m_toolTipFlags & TTRun) {
     if (runtime != knc::numberVarError)
       text += "\n" + i18n("Runtime") + i18n(" : %1:%2 min").arg(min).arg(sec);
-//  else
-//    text += "\n" + i18n("Runtime") +" : ? min";
     }
 
   if (m_toolTipFlags & TTCharge) {
     if (batteryCharge != knc::numberVarError)
       text += "\n" + i18n("Battery Charge") + QString(" : %1 %").arg(batteryCharge);
-// else
-//    text += "\n" + i18n("Battery Charge") + " : ? %";
     }
-                
+
   if (m_toolTipFlags & TTLoad) {
     if (upsLoad != knc::numberVarError)
       text += "\n" + i18n("UPS Load") + QString(" : %1 %").arg(upsLoad);
-//  else
-//    text += "\n" + i18n("UPS Load") + " : ? %";
     }
 
   QToolTip::remove(this);
@@ -629,11 +552,12 @@ void KNutDock::slotRefreshConnection(void) {
   emit makeRefreshConnection();
   }
 
-  
+
 //------------------------------------------
 
 void KNutDock::mousePressEvent(QMouseEvent *e) {
 
+//qDebug("KNutDock::mousePressEvent");
   if( e->button()==LeftButton  ) emit activeMainWindow();
   if( e->button()==RightButton ) m_menu->popup(e->globalPos());
   }
@@ -642,16 +566,37 @@ void KNutDock::mousePressEvent(QMouseEvent *e) {
 
 
 void KNutDock::paintEvent (QPaintEvent *e) {
-  //if (dataOk == ok) {
-  //  bitBlt (this,0,0,mainLayer,0,0,24,24,CopyROP,true);
-  //  }
-  //else KSystemTray::paintEvent(e);
+
   KSystemTray::paintEvent(e);
+  if ((m_activeUpsInfo->upsNet->getState() == KNutNet::Connected) and
+     (m_statusValue != KNutNet::NS)) { // When driver isn't connected, getState is connected and m_statusValue is NS // NONE STATUS
+    if (m_typeOfIcon == pictureKI) {
+      QPainter painter(this);
+//      painter.begin();
+      if (m_statusValue & KNutNet::OL) {  // ONLINE - icon of UPS
+        painter.setPen(Qt::black);
+        paintNumbers (m_upsLoadValue, -2, 15, &painter );
+        }
+      else {  // OFFLINE icon of battery
+        if (m_batteryChargeValue != knc::numberVarError) {
+          if (m_batteryChargeValue < 40) painter.setPen(Qt::red);
+          else painter.setPen(Qt::black);
+          paintNumbers(m_batteryChargeValue,-2,16,&painter);
+          }
+        else {
+          painter.setPen(Qt::black);
+          paintDash (3,16,&painter);
+          paintDash (8,16,&painter);
+          }
+        }
+ //     painter.end();
+      }
+    }
   }
- 
- 
- 
- 
+
+
+
+
 /*********************************************************************************************/
 /*                                                                                           */
 /*                         PRIVATE FUNCTIONS                                                 */
@@ -664,9 +609,9 @@ void KNutDock::clearValues(void) {
   m_runtimeValue = 0;
   m_upsLoadValue = 0;
   m_statusValue = 0;
-  } 
- 
- 
+  }
+
+
 void KNutDock::createUpsMenu(void) {
 
   int n = m_upsRecords->getCount();
@@ -683,7 +628,7 @@ void KNutDock::createMainMenu(void) {
   m_menu = new KPopupMenu;
   m_upsServerMenu = new KPopupMenu;
   createUpsMenu();
-      
+
   m_menu->insertTitle (kapp->miniIcon(),"knutclient");
   m_menu->insertSeparator();
   m_menu->insertItem("UPS",m_upsServerMenu);
@@ -702,8 +647,8 @@ void KNutDock::createMainMenu(void) {
   m_menu->insertSeparator();
   m_menu->insertItem (SmallIcon("exit"),i18n("&Exit"),this ,SLOT(slotExitApplication()));
   }
-  
-     
+
+
 void KNutDock::paintCharge (int charge ) {
   QPainter paint;
 
@@ -747,44 +692,35 @@ void KNutDock::paintCharge (int charge ) {
       paintDash (8,16,&paint);
       }
 
-    }  
+    }
   paint.end();
-  if (m_typeOfIcon != generalKI) bitBlt (m_chargeLayer,0,0,m_batteryLayer,0,0,24,24,AndROP);
   }
 
 
-void KNutDock::paintErrorPoint ( void ) {
-  QPainter paint;
-
-  paint.begin(m_mainLayer);
+void KNutDock::paintErrorPoint ( QPainter& paint ) {
 
+  paint.setPen(QColor(0,0,255));
   paint.setPen(QColor(255,0,0));
-  paint.drawRect(20,18,3,3);
-  paint.setPen(QColor(128,0,0));
-  paint.drawLine(20,19,22,19);
-  paint.drawLine(21,18,21,20);
-  paint.end();
+
+  paint.drawLine(19,18,21,18);
+  paint.drawLine(19,19,21,19);
+  paint.drawLine(19,20,21,20);
   }
 
 
-void KNutDock::paintOKPoint ( void ) {
-  QPainter paint;
-
-  paint.begin(m_mainLayer);
+void KNutDock::paintOKPoint (QPainter& paint  ) {
 
   paint.setPen(QColor(0,255,0));
-  paint.drawRect(20,18,3,3);
-  paint.setPen(QColor(0,128,0));
-  paint.drawLine(20,19,22,19);
-  paint.drawLine(21,18,21,20);
-  paint.end();
+  paint.drawLine(19,18,21,18);
+  paint.drawLine(19,19,21,19);
+  paint.drawLine(19,20,21,20);
   }
-  
-   
+
+
 void KNutDock::paintStatus (int status ) {
   QPainter paint;
   int lastPos = 0;
-   
+
   m_statusLayer->fill(Qt::white);
   paint.begin(m_statusLayer);
 
@@ -825,10 +761,10 @@ void KNutDock::paintStatus (int status ) {
     }
   paint.end();
   }
-   
+
 void KNutDock::paintRuntime (int runtime, int status ) {
   QPainter paint;
-  
+
   m_runtimeLayer->fill(Qt::white);
   paint.begin(m_runtimeLayer);
 
@@ -837,7 +773,7 @@ void KNutDock::paintRuntime (int runtime, int status ) {
   else
     paint.setPen(Qt::black);
   if (runtime != knc::numberVarError) {
-    
+
     int min = abs(runtime/60);
     int sec = runtime - (min*60);
 
@@ -855,12 +791,13 @@ void KNutDock::paintRuntime (int runtime, int status ) {
   paint.drawLine (11,12,11,13);
   paint.drawLine (11,15,11,16);
   paint.end();
-  }   
+  }
 
 void KNutDock::paintLoad (int load ) {
   QPainter paint;
   int myLoad;
 
+//  if (m_typeOfIcon != generalKI) bitBlt (m_loadLayer,0,0,m_upsLayer,0,0,24,24,AndROP);
   m_loadLayer->fill(Qt::white);
   paint.begin(m_loadLayer);
   if (load == knc::numberVarError) myLoad=0;
@@ -871,147 +808,23 @@ void KNutDock::paintLoad (int load ) {
       if (myLoad > 11) myLoad=11;
       if (myLoad < 9) paint.setPen(Qt::green);
       else {
-        if (myLoad < 11) paint.setPen(Qt::yellow);
-        else paint.setPen(Qt::red);
-        }
-      paint.setPen(Qt::green.light(60));
-      for (int i = 0; i < myLoad; i++) {
+      if (myLoad < 11) paint.setPen(Qt::yellow);
+      else paint.setPen(Qt::red);
+      }
+    paint.setPen(Qt::green.light(60));
+    for (int i = 0; i < myLoad; i++) {
       paint.drawLine((i*2)+1,19,(i*2)+1,21);
-        }
-      paint.setPen(Qt::cyan.light(150));
+      }
+    paint.setPen(Qt::cyan.light(150));
       for (int i = myLoad; i < 11; i++) {
         paint.drawLine((i*2)+1,19,(i*2)+1,21);
-        }
-      }  
-    }
-  else { // picture version
-    if (load != knc::numberVarError) {
-      if (myLoad > 12) myLoad=12;
-      if (myLoad > 10) myLoad++; // preskocime rysku pro 100 %
-      if (myLoad < 9) paint.setPen(QColor(0,192,0));
-      else {
-        if (myLoad < 11) paint.setPen(QColor(255,255,0)); //yellow
-        else paint.setPen(QColor(255,0,0));//red
-        }
-      for (int i = 20; i < 23; i++) paint.drawLine(i,13,i,13-myLoad +1);
-    
-      if (myLoad < 13) {
-        paint.setPen(QColor(168,220,255));
-        for (int i = 20; i < 23; i++ ) paint.drawLine(i,1,i,13-myLoad);
-        }
       }
-    paint.setPen(Qt::black);
-    paintNumbers (load, -2, 16, &paint );
-    } // end picture version
+    }
+  }
   paint.end();
 
-  if (m_typeOfIcon != generalKI) bitBlt (m_loadLayer,0,0,m_upsLayer,0,0,24,24,AndROP);
   }
 
-void KNutDock::paintBattery (void) {
-  QPainter paint;
-
-  m_batteryLayer->fill(Qt::white);
-  paint.begin(m_batteryLayer);
-
-  paint.setPen(QColor(128,128,128));//128/128/128
-  paint.drawLine(2,5,20,5);
-
-  paint.setPen(QColor(160,160,160));//160/160/160
-  paint.drawLine(2,6,20,6);
-
-  paint.setPen(QColor(88,88,88));//88/88/88
-  paint.drawLine(2,10,20,10);
-
-  paint.setPen(QColor(48,48,48));//48/48/48
-  paint.drawLine(2,11,20,11);
-
-  paint.setPen(Qt::black);
-  paint.drawLine(1,4,21,4);
-  paint.lineTo(21,12);
-  paint.lineTo(1,12);
-  paint.lineTo(1,4);
-  paint.drawLine(22,6,22,10);
-  
-  paint.drawLine(6,6,6,10);
-  paint.drawLine(11,5,11,11);
-  paint.drawLine(16,6,16,10);
-        
-  paint.drawLine(13,22,17,16);
-  paint.drawRect (13,16,2,2);
-  paint.drawRect (16,21,2,2);
-
-  paint.end();  
-  }
-
-void KNutDock::paintUps (void) {
-  QPainter paint;
-
-  m_upsLayer->fill(Qt::white);
-  paint.begin(m_upsLayer);
-  paint.setPen(Qt::black);
-  paint.drawLine(4,1,4,13);
-  paint.drawLine(5,1,5,13);
-  paint.drawLine(6,1,6,13);
-  paint.drawLine(7,1,7,13);
-  paint.drawLine(8,1,8,13);
-  paint.drawLine(9,1,9,13);
-  paint.drawLine(10,1,10,13);
-  paint.setPen(QColor(0,0,192));// modra
-  paint.drawLine(10,1,10,13);
-  paint.drawLine(11,1,11,13);
-  paint.drawLine(12,1,12,13);
-  paint.drawLine(13,1,13,13);
-
-  paint.setPen(Qt::white);
-  paint.drawPoint (4,7);
-  paint.setPen(QColor(195,195,195));
-  paint.drawPoint (4,6);
-  paint.drawPoint (4,8);
-  paint.setPen(QColor(160,160,160));
-  paint.drawPoint (4,5);
-  paint.drawPoint (4,9);
-  paint.setPen(QColor(128,128,128));
-  paint.drawPoint (4,4);
-  paint.drawPoint (4,10);
-  paint.setPen(QColor(88,88,88));
-  paint.drawPoint (4,3);
-  paint.drawPoint (4,11);
-  paint.setPen(QColor(48,48,48));
-  paint.drawLine(7,10,7,12);
-  paint.drawLine(6,10,6,12);
-
-  paint.setPen(QColor(0,88,192));
-  paint.drawLine (14,6,14,8);
-  paint.setPen(QColor(88,168,255));
-  paint.drawLine (14,4,14,5);
-  paint.drawLine (14,9,14,10);
-  paint.setPen(QColor(168,220,255));
-  paint.drawPoint (14,3);
-  paint.drawPoint (14,11);
-
-  paint.setPen(QColor(0,192,0));
-  paint.drawLine (11,3,13,3);
-  paint.drawLine (12,2,12,4);
-  paint.drawPoint (11,6);
-  paint.drawPoint (13,6);
-  paint.drawPoint (11,8);
-  paint.drawPoint (13,8);
-  paint.setPen(QColor(0,255,0));
-  paint.drawPoint (12,3);
-  paint.setPen(QColor(0,128,0));
-  paint.drawPoint (11,10);
-  paint.drawPoint (13,10);
-
-  paint.setPen(Qt::black);
-  paint.drawLine(19,3,22,3);
-  paint.drawLine(19,14,22,14);
-
-  paint.drawLine(13,22,17,16);
-  paint.drawRect (13,16,2,2);                      
-  paint.drawRect (16,21,2,2);
-  paint.end();
-  }
 
 
 
@@ -1041,7 +854,7 @@ void KNutDock::paintNumbers (int numbers, int x, int y, QPainter* p ) {
     }
   }
 
-                        
+
 void KNutDock::paintDash (int x, int y, QPainter *p) {
 
   p->drawLine(x,y+3,x+3,y+3);
@@ -1051,7 +864,7 @@ void KNutDock::paintNumber (int x, int y, int number, QPainter *p) {
   // x and y are left top corner
 
   if ((number > -1) && (number < 10)) {
-   // kreslim
+   // painting - kreslim
     switch (number) {
       case 0:
       p->drawRect(x,y,4,7);
@@ -1156,7 +969,7 @@ void KNutDock::paintChar (int x, int y, char LCDChar, QPainter *p) {
     break;
     }
   }
-  
+
 
 
 
