@@ -50,7 +50,7 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   setFrameStyle( QFrame::Box | QFrame::Raised );
   setLineWidth( 2 );
-      
+
   if (panelFonts == 0) {
     m_panelFont =kapp->font(); // sets font - system font
     m_panelBoldFont = kapp->font();
@@ -65,9 +65,9 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
   m_mainLayout = new QVBoxLayout(this);
   m_mainLayout->setMargin ( 10 );
   m_mainLayout->setSpacing ( 10 );
-  
+
   // layer for bulbs
-  
+
   m_bulbsGroupBox = new QGroupBox(this);
   m_mainLayout->addWidget(m_bulbsGroupBox);
   m_bulbsGroupBox->setFrameStyle( QFrame::Panel + QFrame::Raised);
@@ -75,7 +75,7 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
   m_bulbsGroupBox->setLineWidth(2);
   QVBoxLayout* bulbsLayout = new QVBoxLayout(m_bulbsGroupBox);
   bulbsLayout->setMargin( 5 );
-  
+
 
   m_textLabel1 = new QLabel( i18n("UPS On line"),m_bulbsGroupBox);
   m_frameOL = new KLed (m_upsBackColor,KLed::Off,KLed::Sunken,KLed::Circular,m_bulbsGroupBox);
@@ -85,10 +85,13 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   QHBoxLayout* OLLayout = new QHBoxLayout(bulbsLayout);
   OLLayout->addWidget(m_textLabel1);
+  OLLayout->addSpacing(10); 
   OLLayout->addWidget(m_frameOL);
   OLLayout->setMargin (3);
+  OLLayout->setStretchFactor(m_textLabel1,20);
+  OLLayout->setStretchFactor(m_frameOL,5);
+
 
-  
   m_textLabel2 = new QLabel( i18n("UPS On battery"), m_bulbsGroupBox);
   m_frameOB = new KLed (m_upsBackColor,KLed::Off,KLed::Sunken,KLed::Circular,m_bulbsGroupBox);
   m_frameOB->setMaximumSize(30,30);
@@ -97,10 +100,13 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   QHBoxLayout* OBLayout = new QHBoxLayout(bulbsLayout);
   OBLayout->addWidget(m_textLabel2);
+  OBLayout->addSpacing(10); 
   OBLayout->addWidget(m_frameOB);
   OBLayout->setMargin (3);
+  OBLayout->setStretchFactor(m_textLabel2,20);
+  OBLayout->setStretchFactor(m_frameOB,5);
+
 
-    
   m_textLabel3 = new QLabel( i18n("UPS Overload"), m_bulbsGroupBox);
   m_frameOVER = new  KLed (m_upsBackColor,KLed::Off,KLed::Sunken,KLed::Circular,m_bulbsGroupBox);
   m_frameOVER->setMaximumSize(30,30);
@@ -109,8 +115,11 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   m_OLayout = new QHBoxLayout(bulbsLayout);
   m_OLayout->addWidget(m_textLabel3);
+  m_OLayout->addSpacing(10); 
   m_OLayout->addWidget(m_frameOVER);
   m_OLayout->setMargin (3);
+  m_OLayout->setStretchFactor(m_textLabel3,20);
+  m_OLayout->setStretchFactor(m_frameOVER,5);
 
   m_textLabel4 = new QLabel( i18n("UPS Battery low"), m_bulbsGroupBox);
   m_frameLB = new  KLed (m_upsBackColor,KLed::Off,KLed::Sunken,KLed::Circular,m_bulbsGroupBox);
@@ -120,9 +129,12 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   m_LBLayout = new QHBoxLayout(bulbsLayout);
   m_LBLayout->addWidget(m_textLabel4);
+  m_LBLayout->addSpacing(10); 
   m_LBLayout->addWidget(m_frameLB);
   m_LBLayout->setMargin (3);
-  
+  m_LBLayout->setStretchFactor(m_textLabel4,20);
+  m_LBLayout->setStretchFactor(m_frameLB,5);
+
   m_textLabel5 = new QLabel( i18n("Replace battery"), m_bulbsGroupBox);
   m_frameRB = new  KLed (m_upsBackColor,KLed::Off,KLed::Sunken,KLed::Circular,m_bulbsGroupBox);
   m_frameRB->setMaximumSize(30,30);
@@ -131,8 +143,11 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   m_RBLayout = new QHBoxLayout(bulbsLayout);
   m_RBLayout->addWidget(m_textLabel5);
+  m_RBLayout->addSpacing(10); 
   m_RBLayout->addWidget(m_frameRB);
   m_RBLayout->setMargin (3);
+  m_RBLayout->setStretchFactor(m_textLabel5,20);
+  m_RBLayout->setStretchFactor(m_frameRB,5);
 
   m_textLabel6 = new QLabel( i18n("UPS calibration"), m_bulbsGroupBox);
   m_frameCAL = new  KLed (m_upsBackColor,KLed::Off,KLed::Sunken,KLed::Circular,m_bulbsGroupBox);
@@ -142,10 +157,13 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   m_CALLayout = new QHBoxLayout(bulbsLayout);
   m_CALLayout->addWidget(m_textLabel6);
+  m_CALLayout->addSpacing(10); 
   m_CALLayout->addWidget(m_frameCAL);
   m_CALLayout->setMargin (3);
+  m_CALLayout->setStretchFactor(m_textLabel6,20);
+  m_CALLayout->setStretchFactor(m_frameCAL,5);
+
 
-  
   m_messGroupBox = new QGroupBox(this);
   m_mainLayout->addWidget(m_messGroupBox);
   m_messGroupBox->setFrameStyle( QFrame::Panel + QFrame::Raised);
@@ -154,7 +172,7 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
   QVBoxLayout* messLayout = new QVBoxLayout(m_messGroupBox);
   messLayout->setMargin( 3 );
 
-  
+
   m_textLabel7 = new QLabel( "", m_messGroupBox);
   QToolTip::add(m_textLabel7,m_textLabel7->text());
   m_manufacModelLayout = new QHBoxLayout(messLayout);
