@@ -25,6 +25,7 @@
 #include <ksimpleconfig.h>
 #include <kstatusbar.h>
 #include <kkeydialog.h>
+#include <kprogress.h>
 
 
 #include <qfont.h>
@@ -39,7 +40,7 @@
 #include <qstringlist.h>
 #include <qlabel.h>
 #include <qsplitter.h>
-#include <qprogressbar.h>
+//#include <qprogressbar.h>
 
 
 
@@ -48,18 +49,21 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-//#include <iostream>
 
 
 extern const char *nameUpsVars1[];
 extern const char *nameUpsVars2[];
 
+const char *descrOfConnection = I18N_NOOP("test of conection from 5");
+
+
 
 KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tActiveUpsInfo, SettingDataDef* tSettingData, KNutUpsData* tUpsRecords, KNutVarData* tAnalogRecords, QWidget* parent, const char *name) : KMainWindow(parent, name),
                    m_listKNutEvent(tListKNutEvent), m_activeUpsInfo(tActiveUpsInfo),m_settingData (tSettingData),
                    m_upsRecords(tUpsRecords), m_analogRecords (tAnalogRecords) {
 
-  
+
+
   initVars();
   initStatusBar();
   initAction();
@@ -88,7 +92,7 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
     m_areaPalette.setColor(QPalette::Inactive,QColorGroup::Background,m_settingData->mainBackgroundColor);
     }
 
-  
+
   // makes main area // Vytvorime hlavni plochu
   m_area = new QLabel (this);
   setCentralWidget (m_area);
@@ -103,7 +107,7 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
     m_mPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,m_settingData->mPanelBackgroundColor);
     }
 
-  QScrollView* panelSV = new QScrollView(m_mainSplit,"panelSV");    
+  QScrollView* panelSV = new QScrollView(m_mainSplit,"panelSV");
   if (m_settingData->customFont)
     m_frontPanel = new KNutFrontPanel (&m_mPanelPalette,m_mainSplit,m_settingData->panelFlags,&(m_settingData->mPanelFont),"FrontPanel");
   else
@@ -117,19 +121,20 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
 
   m_area->setPalette(m_areaPalette);
   m_panelMeter->setPalette(m_areaPalette);
-  
+
   // sets Combo a actives connections to meter panels
   // Nastavime COMBO  a pripadne aktivujeme spojeni na merici panely
   int activeUpsNameIndex = activeMainCombo ();
   if (activeUpsNameIndex != -1) toolBar(0)->getCombo(1)->setCurrentItem( activeUpsNameIndex );
+
   showUpsData();
   setGeometry (m_settingData->x,m_settingData->y,m_settingData->width,m_settingData->height);
   show();
 
-  
+
   //message has to include into status bar after showing window,
   // only for KDE relase < 3.0.0
-  
+
   // jinak se nastavi minimalni velikost ne mensi nez delka aktivni zpravy.
 
   initStatusBarMessage();
@@ -170,6 +175,8 @@ KNutMainWindow::~KNutMainWindow(void) {
 
 void KNutMainWindow::setConfig (unsigned int changeSetting) {
 
+
+//qDebug ("KNutMainWindow::setConfig");
   VarStrucDef analogMemberData;
   bool repaintVoltagePanels = false;
   bool repaintFrequencyPanels = false;
@@ -179,7 +186,7 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
   // Main Setting
 
   // Nastavime zmenu barvy pozadi
-  // We set background color
+  // sets background color
   if (changeSetting & KNutPrefDlg::ChangeCustomBColor) {
     if (!m_settingData->customBColor) { // nastavime barvu pozadi podle systemu 
       m_area->setPalette (m_mainPalette); // we set background color based on system
@@ -205,10 +212,10 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
     }
 
   // Sets background for panels
-  // set frequence
+  // sets frequence
   // sets voltage
   // XFer is switch-on and one exist for this UPS
-  
+
 
   if ((changeSetting & KNutPrefDlg::ChangeXFer) || // je provedena nejaka zmena na napeti nebo frekvence
       (changeSetting & KNutPrefDlg::ChangeVoltage) || (changeSetting & KNutPrefDlg::ChangeFrequency)) {
@@ -246,20 +253,25 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
   }
 
   // Analog setting
-  if ((changeSetting & KNutPrefDlg::ChangeCustomAPanelBColor) || // je provedena zmena barvy panelu, panel color is changed
+  // now DigitalProcesing of pointer
+  if  (changeSetting & KNutPrefDlg::ChangeTypeOfDigProcessing) { //type of digital processing was changed
+     m_panelMeter->changeAnalogPanelsDigProcessing(); //paint pointers with new digotal processing
+     }
+
+  if ((changeSetting & KNutPrefDlg::ChangeCustomAPanelBColor) || // barva panelu je zmenena, panel color is changed
       (changeSetting & KNutPrefDlg::ChangeAPBColor)) {
-  if (m_settingData->customBAnalogColor) {
-    m_aPanelPalette.setColor(QPalette::Active,QColorGroup::Background,m_settingData->aPanelBackgroundColor);
-    m_aPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,m_settingData->aPanelBackgroundColor);
-    repaintAllPanels=true;
-    m_panelMeter->setAnalogBG(m_aPanelPalette);
+    if (m_settingData->customBAnalogColor) {
+      m_aPanelPalette.setColor(QPalette::Active,QColorGroup::Background,m_settingData->aPanelBackgroundColor);
+      m_aPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,m_settingData->aPanelBackgroundColor);
+      repaintAllPanels=true;
+      m_panelMeter->setAnalogBG(m_aPanelPalette);
+      }
+    else {
+      m_aPanelPalette = m_mainPalette;
+      repaintAllPanels=true;
+      m_panelMeter->setAnalogBG(m_aPanelPalette);
+      }
     }
-  else {
-    m_aPanelPalette = m_mainPalette;
-    repaintAllPanels=true;
-    m_panelMeter->setAnalogBG(m_aPanelPalette);
-    }
-  }
 
   if ((changeSetting & KNutPrefDlg::ChangeCustomAPanelOColor) || // je provedena zmena barvy panelu
       (changeSetting & KNutPrefDlg::ChangeAPOColor)) {
@@ -272,8 +284,8 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
        repaintOAPanels=true;
        }
     }
-  // regeneration of panel uses for settingMain and setting Analog 
-  // pregenerovani panelu slozi pro settingMain a setting Analog
+  // regeneration of panel uses for setting Main and setting Analog 
+  // pregenerovani panelu slozi pro setting Main a setting Analog
   m_panelMeter->repaintAnalogPanels (repaintFrequencyPanels, repaintVoltagePanels, repaintAllPanels);
 
   if (m_activeUpsInfo->record.name != "") {
@@ -342,9 +354,12 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
 
 
 
-  
+
 void KNutMainWindow::showUpsData (void) {
 
+//qDebug ("KNutMainWindow::showUpsData start");
+
+
   if ((m_activeUpsInfo->upsNet != 0L) && (!m_activeUpsInfo->netError) &&
      (m_activeUpsInfo->upsDriverState == knc::connected)) {
     int runtimeVal;
@@ -409,7 +424,7 @@ void KNutMainWindow::showUpsData (void) {
       }
     else runtimeVal=knc::numberVarError;
     m_frontPanel->setRuntime(runtimeVal);
-      
+
     m_panelMeter->deActivateAnalogs();
 
     // pokud je pouzito XFER nastavime hodnoty
@@ -430,10 +445,17 @@ void KNutMainWindow::showUpsData (void) {
           }
         }
 
-    m_panelMeter->activateAnalogs();
+//qDebug ("KNutMainWindow::showUpsData 1");
+    m_panelMeter->activateAnalogs(); // makes panel and makes background of panel
+    repaintAnalogs(false);
+//qDebug ("KNutMainWindow::showUpsData 2");
     m_panelMeter->setSize(true);
+//qDebug ("KNutMainWindow::showUpsData 3");
     m_mainSplit->refresh();
-    repaintAnalogs();
+    // doesn't repaint analog pointers, because pointers will be repainted twice
+//qDebug ("KNutMainWindow::showUpsData 4");
+//    repaintAnalogs(false); // don't make this 
+//qDebug ("KNutMainWindow::showUpsData 5");
     }
   else {
     cleanPanels();
@@ -448,7 +470,7 @@ void KNutMainWindow::zeroingPanels (void) {
   m_frontPanel->setPanel(0);
   }
 
-  
+
 void KNutMainWindow::hideUpsData (void) {
   m_frontPanel->cleanPanel();
   }
@@ -473,9 +495,12 @@ void KNutMainWindow::repaintPanel (void) {
   }
 
 
-/// je volan vzdy po timeautu
+/// je volan vzdy po timeoutu
 /// this function is called after timeout always
-void KNutMainWindow::repaintAnalogs (void) {
+void KNutMainWindow::repaintAnalogs ( bool run ) {
+//qDebug ("KNutMainWindow::repaintAnalogs");
+
+
   QString nutStringVar;
   float numVar;
   bool  newRange = false;
@@ -499,6 +524,7 @@ void KNutMainWindow::repaintAnalogs (void) {
       }
     }
 
+//qDebug ("KNutMainWindow::repaintAnalogs 1");
 
   for (int i=0; i< knc::NumberOfVars; i++) {
     if (m_activeUpsInfo->record.upsVarCode[i] != 0) { // jistota pokud by nam to nekde propadlo
@@ -510,26 +536,27 @@ void KNutMainWindow::repaintAnalogs (void) {
           nutStringVar = m_activeUpsInfo->upsNet->readStringVar ((char *)nameUpsVars2[m_activeUpsInfo->record.upsVarCode[i]]);
         break;
         }
+//qDebug ("KNutMainWindow::repaintAnalogs 2 ");
 
       if (nutStringVar.isEmpty())  numVar=0;
       else numVar = nutStringVar.toFloat();
 
       m_panelMeter->repaintScaleAnalogPanel (i, numVar);
       if (newRange) m_panelMeter->repaintAnalogPanels (true, true, false); //freq volt
-      m_panelMeter->repaintAnalogFinger(i,numVar);
+      m_panelMeter->repaintAnalogPointer(i,numVar,run);
       }
     } // end for
+//qDebug ("KNutMainWindow::repaintAnalogs 3 ");
   }
 
 
 
-  void KNutMainWindow::cleanPanels (void) {
-  
-    m_frontPanel->cleanPanel();
-    m_panelMeter->deActivateAnalogs();
-    m_panelMeter->setSize(false);
-    m_mainSplit->refresh();
+void KNutMainWindow::cleanPanels (void) {
 
+  m_frontPanel->cleanPanel();
+  m_panelMeter->deActivateAnalogs();
+  m_panelMeter->setSize(false);
+  m_mainSplit->refresh();
   }
 
 void KNutMainWindow::startConnectPB ( const int count ) {
@@ -538,17 +565,18 @@ void KNutMainWindow::startConnectPB ( const int count ) {
   m_connectProggresBar->show();
   }
 
-  
+
 void KNutMainWindow::setProgressConnectPB ( const int progress ) {
   m_connectProggresBar->setProgress(progress);
   }
-  
-  
+
+
 void KNutMainWindow::hideConnectPB ( void ) {
+  m_connectProggresBar->setProgress(0);
   m_connectProggresBar->hide();
-  }        
-  
-  
+  }
+
+
 /*********************************************************************************************/
 /*                                                                                           */
 /*                         PRIVATE SLOTS                                                     */
@@ -556,17 +584,22 @@ void KNutMainWindow::hideConnectPB ( void ) {
 /*********************************************************************************************/
 
 
+//this SLOT is for older KDE only
 void KNutMainWindow::slotShowToolBar(void) {
-  statusBar()->message(i18n("Toggle the toolbar..."),2000);
+
   if(toolBar("mainToolBar")->isVisible()) toolBar("mainToolBar")->hide();
   else toolBar("mainToolBar")->show();
   }
 
 
 void KNutMainWindow::slotShowStatusBar(void) {
-  statusBar()->message(i18n("Toggle the statusbar..."),2000);
-  if(statusBar()->isVisible()) statusBar()->hide();
-  else statusBar()->show();
+
+  if(statusBar()->isVisible()) {
+    statusBar()->hide();
+    }
+  else {
+    statusBar()->show();
+    }
   }
 
 void KNutMainWindow::slotDescription(void) {
@@ -600,7 +633,6 @@ void KNutMainWindow::slotRefreshConnection(void) {
   }
 
 
-//void KNutMainWindow::slotChangeRWVars ( QString varName) {
 void KNutMainWindow::slotChangeRWVars ( QString ) {
   }
 
@@ -618,7 +650,7 @@ void KNutMainWindow::slotConfigureKeys() {
   KKeyDialog::configure( actionCollection(), this );
   }
 
-  
+
 void KNutMainWindow::slotCloseKnutClient (void) {
   if (m_settingData->areYouSure) {
     if (KMessageBox::warningYesNo (0,i18n("Are you sure ?")) == 3) 
@@ -629,16 +661,16 @@ void KNutMainWindow::slotCloseKnutClient (void) {
 
 
 
-  
+
   void KNutMainWindow::slotChangeUPS (const QString &name) {
   emit UPSChanged (name);
   }
 
-  
+
 void KNutMainWindow::slotPreferencesUps() {
     emit preferenceUps();
   }
-  
+
 
 /*********************************************************************************************/
 /*                                                                                           */
@@ -652,14 +684,22 @@ void KNutMainWindow::initStatusBar ( void ) {
   // sets main message if statusbar
   // nastavime hlavni hlaseni v statusbaru
 
+ // QString progressString("%v ");// += descrOfConnection;
+//  progressString.append(descrOfConnection);
+
+  m_progressFormatString.append("%v ");
+  m_progressFormatString.append(descrOfConnection);
   m_infoCombo = new KComboBox (statusBar(),"infoCombo");
   m_infoCombo->setMaxCount(knc::maxCountKNutEvent+1); // nastavime maximalni pocet polozek v Combu
                                                  // pro rezervu pridame jeste jednu
 //sets maximal if items in Combo 
   statusBar()->addWidget(m_infoCombo,10,false);
-  
-  m_connectProggresBar = new QProgressBar(statusBar(),"connectProgressBar");
+
+  m_connectProggresBar = new KProgress(statusBar(),"connectProgressBar");
   statusBar()->addWidget(m_connectProggresBar,5,false);
+  m_connectProggresBar->setProgress(0);
+//  m_connectProggresBar->setFormat("%v test of conection from 5");
+  m_connectProggresBar->setFormat(m_progressFormatString);
   m_connectProggresBar->hide();
   }
 
@@ -673,8 +713,8 @@ void KNutMainWindow::initStatusBarMessage ( void ) {
     }
   statusBar()-> setItemAlignment(0,Qt::AlignHCenter|Qt::AlignVCenter);
   m_infoCombo->setCurrentItem(m_infoCombo->count()-1);
-  }  
-  
+  }
+
 
 void KNutMainWindow::initToolBar ( void ) {
 
@@ -701,9 +741,35 @@ void KNutMainWindow::initAction ( void ) {
   new KAction(i18n("&Showing UPS variables and commands"),0,this,SLOT(slotPrintUPSVars()),actionCollection(),"printupsvars");
   new KAction(i18n("&Running instant commands"),0,this,SLOT(slotInstComms()),actionCollection(),"instcomms");
   new KAction(i18n("Setting R&W variables"),0,this,SLOT(slotRWVars()),actionCollection(),"rwvars");
-  KStdAction::showToolbar (this, SLOT (slotShowToolBar()), actionCollection());
+
+///////////////////
+//   KStdAction::showToolbar (this, SLOT (slotShowToolBar()), actionCollection()); 
+//  setStandardToolBarMenuEnabled(true); since KDE version 3.1
+
+// since version 3.1
+  #if defined  (KDE_VERSION_MAJOR)
+    #if KDE_VERSION_MAJOR >= 3
+      #if defined  (KDE_VERSION_MINOR)
+        #if KDE_VERSION_MINOR >= 1
+          setStandardToolBarMenuEnabled(true);
+        #else
+          KStdAction::showToolbar (this, SLOT (slotShowToolBar()), actionCollection());
+        #endif
+      #else
+        KStdAction::showToolbar (this, SLOT (slotShowToolBar()), actionCollection());
+      #endif
+    #else
+      KStdAction::showToolbar (this, SLOT (slotShowToolBar()), actionCollection());
+    #endif
+  #else
+    KStdAction::showToolbar (this, SLOT (slotShowToolBar()), actionCollection());
+  #endif
+
+
   KStdAction::showStatusbar (this, SLOT (slotShowStatusBar()), actionCollection());
+
   m_descriptionAction = new KToggleAction(i18n("&Using descriptions"),0,this,SLOT(slotDescription()),actionCollection(),"use_description");
+
   KStdAction::keyBindings( this, SLOT(slotConfigureKeys()),actionCollection());
   new KAction (i18n("Reconnect"),"reload",Key_F5,this,SLOT(slotRefreshConnection()),actionCollection(),"reconnect");
   }
