@@ -29,13 +29,6 @@
 #include <qnetworkprotocol.h>
 #include <qmutex.h>
 
-
-//#include <sys/time.h>
-//#include <sys/types.h>
-//#include <arpa/inet.h>
-//#include <netinet/in.h>
-
-
 #include <qvaluevector.h>
 
 
@@ -62,7 +55,7 @@ class QString;
 class QCString;
 class QSocket;
 class QTimer;
-            
+
 
 /**
   *@author Daniel Prynych
@@ -91,7 +84,7 @@ public:
   enum NetState {Idle, HostLookup, Connecting, Connected, ConnectError,Closing };
   // idle is same like NotConnected
   // neni pripojeno chyba pri pripojeni,pripojeno, pripojuji
-  
+
 
   enum typeOfVar {AllVars, ROVars, RWVars };
 
@@ -120,7 +113,7 @@ public:
     CommNotFind,   // command hasn't been found  in list of module's commands - prikaz nebyl nalezen v seznamu prikazu modulu
     VarNotFind,    // variable hasn't been found in list of module's variables promena nebyla nalezena v seznamu promenych modulu
     EnumValueNotFind, //value of enumereted variable hasn't been found hodnota vyctove promene nebyla nalezena
- 
+
 // tyto zpravy vraci server
 // this mesages is returned server upsd
     AccessDenied,        // access denied - pristup odmitnut
@@ -129,11 +122,12 @@ public:
     UnknownUps,          // this ups isn't occured on address - tato ups neni na zadane adrese
     AlreadyLoggedIn,     // prihlaseni LOGIN jiz bylo provedeno
     AlreadySetPassword,  // password has been already entered  - heslo jiz bylo zadano
+    AlreadySetUsername,  // username has been already entered  - uzivatelske jmeno jiz bylo zadano
     DataStale,           // data from module isn't got - neni mozne ziskat z modulu nove data 
     MissingArgument,     // misses argument - chyby argument
     UnknownType,         // unknown type of variable -neznamy typ promene
     UnknownCommand,      // umknown command example: sends maybe "UPERNAME admin"  - nezmamy  prikaz pr: poslem treba "UPERNAME admin"
-    
+
     //tyto chyby se vztahuji k driveru pro danny typ UPS-ky
     // this mistake is refered for   selected driver of UPS
     DriverNotConnected,  // driver isn't connected -  driver neni pripojen
@@ -146,9 +140,12 @@ public:
     InvalidValue,        // unknown value - nespravna hodnota
     UnknownInstCmd,      // unknown instant command / neznamy okamzity prikaz
     CmdNotSupported,     // this instant command isn't supported - tento okamzity prikaz neni podporovan
-    NotConnection};      // operace nelze provest protoze neni provedeno pripojeni
+    NotConnection,      // operace nelze provest protoze neni provedeno pripojeni
+    // this not error 
+    NoListVars};        //upsd doesn't return list of variables, variable for STATUS has got value WAIT
 
   enum typeOfStatus {
+    NS = 0,     // - NONE status of UPS wasn't read
     OFF = 1,    // - UPS is off (not supplying power)
     OL = 2,     // - UPS is online (supplying power from the line/mains)
     OB = 4,     // - UPS is on battery
@@ -157,8 +154,9 @@ public:
     TRIM = 32,  // - UPS is trimming incoming voltage (APC "SmartTrim")
     BOOST = 64, // - UPS is boosting incoming voltage (APC "SmartBoost")
     OVER = 128, // - UPS is overloaded
-    RB = 256   // - UPS battery needs to be replaced
-    }; 
+    RB = 256,   // - UPS battery needs to be replaced
+    WAIT = 512   // - UPS as for waiting
+    };
 
   enum keyWord {
     NONE,
@@ -195,49 +193,49 @@ public:
     STRING_FLAG = 4
     };  
 
-    
-    
+
+
 /**
  * Constructor sets basic variables and structures only, but doesn't read variables from server NUT
  * Konstruktor pouze nastavi zakladni promene a struktury, ale necte promene se serveru NUT.
- * @param tUpsName in name of UPS 
- * @param tUpsName Je jmeno UPSky 
- * @param tUpsAddress Is address of UPS (adresa pocitace na ktery je UPS pripojena)
+ * @param upsName in name of UPS 
+ * @param upsAddress Is address of UPS (adresa pocitace na ktery je UPS pripojena)
  * netAddress can is entered like ip address or domain name
  * example: localhost karel.domain,cz 194.212.25.55.
  * @param tPort Is name if port, for NUT server (NUT is received on this port), default is 3493.
- * @param tDelay is delay in msec. System waits  before one tries to make connection again. When test of connection fails,
- * @param tCountRepeat is maximal number of repeating for make connection. 
+ * @param delay is delay in msec. System waits  before one tries to make connection again. When test of connection fails,
+ * @param countRepeat is maximal number of repeating for make connection. 
  *
  * Since 0.7.5 version protocol UDP is not supported
- * @param tUpsAddress Je adresa ups-ky (adresa pocitace na ktery je UPS pripojena)
+ * @param upsAddress Je adresa ups-ky (adresa pocitace na ktery je UPS pripojena)
  * netAddress muze byt zadan jako ip adresa nebo domenove jmeno pocitace
+ * @param upsName je jmeno UPSky 
  * pr.: localhost  karel.domena.cz 194.212.25.55.
- * @param tPort Je cislo portu na kterem nasloucha NUT server, default je 3493.
- * @param tDelay Je zpozdeni v msec, Sustem ceka nez znovu pokusi ukutecnit spojeni. Kdyz pokus o spojeni selhal.
- * @param tCountRepeat je maximalni pocet opakovani spojeni pro navazani spojeni. 
+ * @param tPort je cislo portu na kterem nasloucha NUT server, default je 3493.
+ * @param delay je zpozdeni v msec, System ceka nez znovu pokusi ukutecnit spojeni. Kdyz pokus o spojeni selhal.
+ * @param countRepeat je maximalni pocet opakovani spojeni pro navazani spojeni. 
  * Od verze 0.7 neni podporovano UDP
  *
  * @since  0.7.5
  **/
-  KNutNet (const QString tUpsAddress, const QString tUpsName="", const unsigned short tPort=3493, unsigned int tCountRepeat =0, const unsigned int tDelay = 200);
-  
+  KNutNet (const QString upsAddress, const QString upsName="", const unsigned short port=3493, unsigned int countRepeat =0, const unsigned int delay = 200);
+
 /**
  * @since  0.5
  **/
   ~KNutNet();
 
-  
-  
+
+
 /** 
  * Zavre spojeni a nastavi hodnoty pro novou UPSku
  * Closes conneting and sets values for new UPS
  *
  * @since  0.1
  **/
- void newUPS (const QString tUpsAddress, const QString tUpsName, const unsigned short tPort=3493);
-   
-  
+ void newUPS (const QString upsAddress, const QString upsName, const unsigned short port=3493);
+
+
 /**
  * Provadi spojeni
  * Makes conneting
@@ -245,7 +243,7 @@ public:
  * @since  0.1
  **/
   void open (void);
-  
+
 /** 
  * Zavre spojeni
  * Closes conneting
@@ -253,7 +251,7 @@ public:
  * @since  0.1
  **/
  void close (void);
-  
+
 
 /**
  * Returns kod of error, which is setted after last colling of same function this calls.
@@ -286,7 +284,7 @@ public:
  * @since  0.5
  **/
   bool isDescription ( void );
-  
+
 
 /**
  * Vraci zda doslo k prepnuti z UDP do TCP;
@@ -295,7 +293,7 @@ public:
  * @since  0.1
  **/
 bool switchedToTCP ( void );
-  
+
 
 /**
  * Vraci cislo protokolu pro komunikaci s NUT
@@ -317,18 +315,18 @@ bool switchedToTCP ( void );
  **/
   int getNutVariables ( void );
 
-        
-  
+
+
 /**
  * Nacte vsechny promene UPS-ky a nastavi jejich typ (znakove/char, vyctove/enum a status)
- * nastavi priznak aktivity jen pro status.
+ * Nastavi priznak aktivity jen pro status.
  * Funkce vraci kod chyby nebo 0 pokud k chybe nedojde;
- * Od verze 0.6 jsou nacteny vzdy i hodnoty promenych
+ * Vzdy jsou nacteny i hodnoty promenych.
  *
  * @since  0.6.1
  **/
   int getUpsVars ( void);  
-  
+
 
 /**
  * Nacte hodnoty vsech promenych UPS-ky pokud je nastaven jejich priznak aktivity,
@@ -345,6 +343,7 @@ bool switchedToTCP ( void );
 
 /**
  * Nacte popisy pro kazdou promennou
+ * Read descriptions for every variable
  *
  * @param always Urcuje zda se nacteny provede vzdy nebo jen kdy popis jeste
  * nebyl nacten.
@@ -367,7 +366,7 @@ bool switchedToTCP ( void );
  * @since  0.7
  **/
   int instantCommand (const QString command, const QString userName, const QString password, const bool onlyCommand = false);
-  
+
 
 /**
  * Nastavi RW promenou.
@@ -442,7 +441,7 @@ bool switchedToTCP ( void );
  * @since  0.6
  **/
   int readVars (const int seqNumber, struct upsVar& allVar, const typeOfVar typVar = AllVars);
-      
+
 
 /**
  * Vrati hodnotu promenne.
@@ -483,7 +482,7 @@ bool switchedToTCP ( void );
  **/
 int readStatus(void);
 
-  
+
 /**
  * Nastavi priznak aktivity.
  * Pri chybe vrati kod chyby.
@@ -513,7 +512,7 @@ int readStatus(void);
   int unSetActivateAll ( void );
 
 
-  
+
 /**
  * Testuje zda existuje promena danneho jmena.
  * POZOR ZMENA v NAVRATOVYCH HODNOTACH
@@ -539,7 +538,7 @@ signals:
  * param@ error je cislo chyby.
  * param@ error je value of error.
  **/
-void connectionError(int error);                                                                                            
+void connectionError(int error);
 
 
 /**
@@ -548,9 +547,8 @@ void connectionError(int error);
  *
  * @since  0.1
  **/
-void connectionClosed (void);                                                                                                
+void connectionClosed (void);
 
-                              
 /**
  * Signal je vyslan, kdyz dojde k prvemu spojeni se serverem.
  * Signal is emited, when the first connection with server is realized
@@ -563,14 +561,14 @@ void firstConnection(void);
  *
  * @since  0.1
  **/
-void nextConnection(void);                                                                                                                                                       
+void nextConnection(void);
  /**
  * Signal je vyslan, kdyz prevod jmena byl uspesny.
  * Signal is emited, when host lookup has succeeded
  *
  * @since  0.1
  **/
-void hostFound(void);                                                                                                   
+void hostFound(void);
 
 
  /**
@@ -596,7 +594,7 @@ void tryFirstConnection( int);
   void getVarDesc (int count, int item);
 
 /*********   Private part    **********/
-  
+
   private:
 
 // internal funkcion
@@ -702,7 +700,7 @@ int getFirstUpsName (QString& firstUpsName);
  * Jen pro protokol verze 2
  * Funkce vraci kod chyby nebo 0 pokud k chybe nedojde;
  *
- * @since  0.1
+ * @since  0.2
  **/
   int getUpsVars2 ( void);
 
@@ -732,7 +730,7 @@ int getFirstUpsName (QString& firstUpsName);
  **/
   int getUpsValues2 (const bool allVars );
 
-            
+
 /**
  * @internal
  * Zjisti verzi upsd
@@ -741,7 +739,7 @@ int getFirstUpsName (QString& firstUpsName);
  * @param delay zpozdeni, cas mezi opakovani
  */
   int version (int countRepeat, const int delay);
-  
+
 
 /**
  * @internal
@@ -759,7 +757,7 @@ int getFirstUpsName (QString& firstUpsName);
  * @internal
  */
 void upsSetType (struct upsVar& uVar, const QString name, const QString value = "");
-  
+
 /**
  * @internal
  */
@@ -788,7 +786,7 @@ void upsSetType (struct upsVar& uVar, const QString name, const QString value =
  * Nenastavuje promenou error.
  */
  int sendComm (const QString command, const QString arg1, const QString arg2, const bool useUpsName=false);
-      
+
 
 /**
  * @internal
@@ -800,7 +798,7 @@ void upsSetType (struct upsVar& uVar, const QString name, const QString value =
  * @internal
  */
   int activateAll ( const bool setActivate );
-  
+
 
 /**
  * @internal
@@ -811,65 +809,60 @@ private slots:
   void slotConnectionError(int error);
 
   void slotConnected(void);
- 
+
   void slotTimerReconnect(void);
 
   void slotHostFound(void);
 
   void slotConnectionClosed(void);
-  
+
   void slotClosed (void);
-  
 
-private:  
-                  
+
+private:
+
   /******* CONST ********/
- // static const int upsGetTimeout1 = 2; // doba cekani na navrat paketu
-//  static const int upsGetTimeout2 = 1; // doba cekani na navrat paketu pro druhy test - jen UDP
-//  static const int upsGetTimeout3 = 1; // doba cekani na navrat paketu pro docitani
 
-  QSocket *commandSocket;
-  QTimer* unConnectTimer;
+  static const Q_ULONG rBufferLen = 1024;
+
+  QSocket *m_commandSocket;
+  QTimer* m_unConnectTimer;
+
 
-  
   /****** VARS *************/
-  QString upsAddress;
-  QString upsName;
+  QString m_upsAddress;
+  QString m_upsName;
 
-  unsigned int countRepeat;
-  unsigned short port;
-  unsigned int delay;
+  unsigned int m_countRepeat;
+  unsigned short m_port;
+  unsigned int m_delay;
 
-  NetState state;
-  int error;
-  bool firstConnect;
-  unsigned int numberConnection;
+  NetState m_state;
+  int m_error;
+  bool m_firstConnect;
+  unsigned int m_numberConnection;
 
-      
-
-  int nutProtocol;  // 1 for NUT <1.3,  2 for NUT => 1.3
-  int nutVariables; // 1 for NUT <1.3,  2 for NUT => 1.3
+  int m_nutProtocol;  // 1 for NUT <1.3,  2 for NUT => 1.3
+  int m_nutVariables; // 1 for NUT <1.3,  2 for NUT => 1.3
 
 
-  int numberVars; // number of all variables - pocet vsech promennych
-  int numberRWVars;
-  int numberIComms;
+  int m_numberVars; // number of all variables - pocet vsech promennych
+  int m_numberRWVars;
+  int m_numberIComms;
 
-  int upsStatusVar;
-  bool description;
+  int m_upsStatusVar;
+  bool m_description;
 
-  bool switchToTCP;
-  
-  QMutex getUpsDataMutex;
-  
+  bool m_switchToTCP;
 
+  QMutex m_getUpsDataMutex;
 
-  QValueVector<upsVar> listVars;
-  QValueVector<upsIComm> listIComms;
+  QValueVector<upsVar> m_listVars;
+  QValueVector<upsIComm> m_listIComms;
 
 /********* Pomocne promenne ***********/
-  int posChar;
-   
+  int m_posChar;
+
 };
 
 #endif
