@@ -44,7 +44,7 @@ KNutPrefDlg::KNutPrefDlg(KNutUpsData* const upsData, KNutVarData* const analogDa
                           const QString upsName, QWidget* parent,  const char* name, const bool modal)
             :KDialogBase(IconList, i18n("Preferences"),Help|Default|Apply|Ok|Cancel,Ok, parent, name, modal, true),
                          m_activeUpsName (upsName), m_myUpsData(upsData), m_myAnalogData(analogData), m_prefData(settingData) {
-          
+
 
   setName( "UpsMemberDlg" );
 
@@ -64,7 +64,7 @@ KNutPrefDlg::KNutPrefDlg(KNutUpsData* const upsData, KNutVarData* const analogDa
 KNutPrefDlg::~KNutPrefDlg(){
   delete m_listBox2;
   }
-  
+
 
 
 
@@ -73,7 +73,25 @@ KNutPrefDlg::~KNutPrefDlg(){
 /*                         PRIVATE SLOTS                                                     */
 /*                                                                                           */
 /*********************************************************************************************/
-  
+
+
+void KNutPrefDlg::slotSetPictureKI (bool on) {
+if (!on) {
+  m_checkBoxCbi->setEnabled(true);
+  m_iconDockLabel->setEnabled(true);
+  m_BGIButton->setEnabled(m_checkBoxCbi->isChecked());
+  m_dockBackgroundColorLabel->setEnabled(m_checkBoxCbi->isChecked());
+
+  }
+else {
+  m_checkBoxCbi->setEnabled(false);
+  m_iconDockLabel->setEnabled(false);
+  m_BGIButton->setEnabled(false);
+  m_dockBackgroundColorLabel->setEnabled(false);
+
+  }
+
+}
 
 void KNutPrefDlg::slotEnableVoltage(bool enable) { m_voltageGroup->setEnabled(!enable);}
 
@@ -89,7 +107,7 @@ void KNutPrefDlg::slotUseCustomBIconColor(bool enable) {
   m_dockBackgroundColorLabel->setEnabled(enable);
   }
 
-  
+
 void KNutPrefDlg::slotUseCustomBPanelColor(bool enable) {
   m_BGPButton->setEnabled(enable);
   m_panelBackgroundColorLabel->setEnabled(enable);
@@ -115,7 +133,7 @@ void KNutPrefDlg::slotUseCustomOAnalogColor(bool enable) {
   m_analogFontColorLabel->setEnabled(enable);
   }
 
-  
+
 
 void KNutPrefDlg::slotChangeSettingFont(int index) {
   if (m_settingFont != index) {
@@ -221,12 +239,12 @@ void KNutPrefDlg::slotApply() {
     m_prefData->customBColor = m_checkBoxCbc->isChecked();
     changeSetting += ChangeCustomBColor;
     }
-                           
+
   if (m_prefData->mainBackgroundColor != m_BGButton->color()) {
     changeSetting += ChangeMBColor;
     m_prefData->mainBackgroundColor = m_BGButton->color();  // nastavime barvu pozadi
     }
-         
+
   // ovlivnuje jen ukonceni programu, neurcujeme type ChangeSetting
   if (m_prefData->areYouSure != m_checkBoxAys->isChecked()) {
     m_prefData->areYouSure = m_checkBoxAys->isChecked();
@@ -243,8 +261,8 @@ void KNutPrefDlg::slotApply() {
     m_prefData->useMessageWindow = m_checkBoxMesW->isChecked();
     changeSetting = changeSetting | ChangeSomeThing;
     }
-    
-      
+
+
   int newInputVoltage, newInputFrequency;
   if ( m_vRadioButton1->isChecked()) newInputVoltage = 230; else newInputVoltage = 120;
   if ( m_fRadioButton1->isChecked()) newInputFrequency = 50; else newInputFrequency = 60;
@@ -298,7 +316,7 @@ void KNutPrefDlg::slotApply() {
     }
 
 
-                          
+
     // font Page:
     unsigned int changeFonts;
     changeFonts =0;
@@ -361,14 +379,19 @@ void KNutPrefDlg::slotApply() {
       (m_prefData->analogScaleColor != m_AScaleButton->color()) ||
       (m_prefData->analogFontColor != m_AFontButton->color())) {
     changeSetting += ChangeAPOColor;
-    m_prefData->analogFingerColor = m_AFingerButton->color();  // nastavime barvu rucicky
-    m_prefData->analogOKColor = m_AOKButton->color();  // nastavime barvu ok
+    m_prefData->analogFingerColor = m_AFingerButton->color();  // sets color of pointers-- nastavime barvu rucicky
+    m_prefData->analogOKColor = m_AOKButton->color();  // sets color of OK --  nastavime barvu ok
     m_prefData->analogWarnningColor = m_AWarnningButton->color();  // nastavime barvu varovano
     m_prefData->analogErrorColor = m_AErrorButton->color();  // nastavime barvu chyby
     m_prefData->analogScaleColor = m_AScaleButton->color();  // nastavime barvu stupnice
     m_prefData->analogFontColor = m_AFontButton->color();  // nastavime barvu textu
     }
-    
+
+  if (m_prefData->typeDigitalProcessing != m_digitalProcesingOfPointers->currentItem()) {
+    m_prefData->typeDigitalProcessing = m_digitalProcesingOfPointers->currentItem();
+    changeSetting += ChangeTypeOfDigProcessing;
+    }
+
   // Kicker Icon page
 
   int stateKIcon;
@@ -403,7 +426,7 @@ void KNutPrefDlg::slotApply() {
     m_prefData->toolTipFlags = prefToolTipFlags;
     changeSetting += ChangeToolTip;
     }
-            
+
   if (changeSetting)  emit signalChangeConfig( changeSetting );
   }
 
@@ -488,7 +511,7 @@ void KNutPrefDlg::initSetting () {
   QLabel *initSettingLabel2 = new QLabel(i18n("Use custom background color"),dataBox,"label2");
   m_checkBoxCbc = new QCheckBox ("",dataBox,"checboxcbc");
 
-  
+
   m_mainBackgroundColorLabel = new QLabel(i18n("Color of background :"),dataBox,"label3");
   m_BGButton = new KColorButton (dataBox);
   m_BGButton->setColor (m_prefData->mainBackgroundColor);
@@ -498,12 +521,12 @@ void KNutPrefDlg::initSetting () {
 
   QLabel *initSettingLabel5 = new QLabel(i18n("Use Main window when program is started"),dataBox,"initSettingLabel5");
   m_checkBoxMW = new QCheckBox ("",dataBox,"checboxmv");
-  
+
   QLabel *initSettingLabel6 = new QLabel(i18n("Show message window, when program reports error"),dataBox,"initSettingLabel6");
   m_checkBoxMesW = new QCheckBox ("",dataBox,"checboxer");
-  
-  
-  
+
+
+
 
   m_voltageGroup = new QButtonGroup(i18n("Nominal Input Voltage"),VFGroup,"voltageGroup");
   QGridLayout *voltLayout = new QGridLayout (m_voltageGroup, 3 , 1,spacingHint () );
@@ -528,7 +551,7 @@ void KNutPrefDlg::initSetting () {
 
   dataLayout->addWidget (initSettingLabel4,3,0);
   dataLayout->addWidget (m_checkBoxAys,3,1);
-  
+
   dataLayout->addWidget (initSettingLabel5,4,0);
   dataLayout->addWidget (m_checkBoxMW,4,1);
 
@@ -576,7 +599,7 @@ void KNutPrefDlg::initSetting () {
   connect (m_xfer,SIGNAL(toggled(bool)),this,SLOT(slotEnableVoltage(bool)));
   connect (m_xfer,SIGNAL(toggled(bool)),this,SLOT(slotEnableFrequency(bool)));
 
-  
+
   m_checkBoxCbc->setChecked(m_prefData->customBColor); 
   m_BGButton->setColor(m_prefData->mainBackgroundColor);
   m_BGButton->setEnabled(m_prefData->customBColor);
@@ -618,7 +641,7 @@ void KNutPrefDlg::initUps () {
   connect (editButton,SIGNAL(clicked()),this,SLOT(slotEditUps()));
   connect (deleteButton,SIGNAL(clicked()),this,SLOT(slotDeleteUps()));
   connect (m_listBox2,SIGNAL(doubleClicked(QListBoxItem*, const QPoint&)),this,SLOT(slotEditUps()));
-  
+
   }
 
 void KNutPrefDlg::initDock () {
@@ -642,7 +665,7 @@ void KNutPrefDlg::initDock () {
   m_iconRadioButton1 = new QRadioButton(i18n("&Picture"), typeGroup, "iconRadioButton1" );
   m_iconRadioButton2 = new QRadioButton(i18n("&General"), typeGroup, "iconRadioButton2" );
 
-  
+
   m_checkBoxTTMFR = new QCheckBox (i18n("M&anufacturer"),infoBox);
   m_checkBoxTTMFR->setChecked((m_prefData->toolTipFlags) & KNutDock::TTMFR);
 
@@ -663,9 +686,9 @@ void KNutPrefDlg::initDock () {
 
   m_checkBoxTTLoad = new QCheckBox (i18n("&UPS Load"),infoBox);
   m_checkBoxTTLoad->setChecked((m_prefData->toolTipFlags) & KNutDock::TTLoad);
-  
-  
-  QLabel *initDockLabel1 = new QLabel(i18n("Use custom icon's background color"),page,"label1");
+
+
+  m_iconDockLabel = new QLabel(i18n("Use custom icon's background color"),page,"label1");
   m_checkBoxCbi = new QCheckBox ("",page,"checboxcbpc");
 
   m_dockBackgroundColorLabel = new QLabel(i18n("Color of icon's background :"),page,"label12");
@@ -679,7 +702,7 @@ void KNutPrefDlg::initDock () {
     m_iconRadioButton1->setChecked( true );
   if (m_prefData->typeOfKIcon == KNutDock::generalKI)
     m_iconRadioButton2->setChecked( true );
-  
+
   infoLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
   infoLayout->addWidget ( m_checkBoxTTMFR ,1,0);
   infoLayout->addWidget ( m_checkBoxTTModel ,2,0);
@@ -688,23 +711,36 @@ void KNutPrefDlg::initDock () {
   infoLayout->addWidget ( m_checkBoxTTRun ,5,0);
   infoLayout->addWidget ( m_checkBoxTTCharge ,6,0);
   infoLayout->addWidget ( m_checkBoxTTLoad ,7,0);
-  
-  colorLayout->addWidget (initDockLabel1,0,0);
+
+  colorLayout->addWidget (m_iconDockLabel,0,0);
   colorLayout->addWidget (m_checkBoxCbi,0,1);
   colorLayout->addWidget (m_dockBackgroundColorLabel,1,0);
   colorLayout->addWidget (m_BGIButton,1,1);
 
   m_checkBoxCbi->setChecked(m_prefData->customKIconColor);
   m_BGIButton->setColor(m_prefData->kIconBackgroundColor);
-  m_BGIButton->setEnabled(m_prefData->customKIconColor);
-  m_dockBackgroundColorLabel->setEnabled(m_prefData->customKIconColor);
+//  m_BGIButton->setEnabled(m_prefData->customKIconColor);
+//  m_dockBackgroundColorLabel->setEnabled(m_prefData->customKIconColor);
+
+  if (m_iconRadioButton1->isChecked()) {
+    m_iconDockLabel->setEnabled(false);
+    m_checkBoxCbi->setEnabled(false);
+    m_BGIButton->setEnabled(false);
+    m_dockBackgroundColorLabel->setEnabled(false);
+    }
+  else {
+    m_iconDockLabel->setEnabled(true);
+    m_BGIButton->setEnabled(m_prefData->customKIconColor);
+    m_dockBackgroundColorLabel->setEnabled(m_prefData->customKIconColor);
+    }
 
-  
   setTopLayout->addStretch( 20 );
 
   connect (m_checkBoxCbi,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBIconColor(bool)));
+  connect (m_iconRadioButton1,SIGNAL(toggled(bool)),this,SLOT(slotSetPictureKI(bool)));
+
   }
-  
+
 
 void KNutPrefDlg::initPanel () {
   QFrame *page = addPage( i18n("Panel"),i18n("Panel Setting"),DesktopIcon("panel_settings"));
@@ -825,7 +861,7 @@ void KNutPrefDlg::initFonts () {
 void KNutPrefDlg::initAnalog () {
   QFrame *page = addPage( i18n("Analog"),i18n("Setting Analog panel"),DesktopIcon("ksysguard"));
   QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
-  QGridLayout *setColorLayout = new QGridLayout( 8,2, spacingHint(),"setColorLayout");
+  QGridLayout *setColorLayout = new QGridLayout( 9,2, spacingHint(),"setColorLayout");
   setTopLayout->addLayout(setColorLayout);
   setTopLayout->addStretch( 20 );
 
@@ -848,6 +884,9 @@ void KNutPrefDlg::initAnalog () {
   m_analogFontColorLabel = new QLabel(i18n("Color of font :"),page,"label11");
   m_AFontButton = new KColorButton (page);
 
+  m_digitalProcessingLabel = new QLabel(i18n("Digital processing of pointers :"),page,"label12");
+  m_digitalProcesingOfPointers = new KComboBox (page);
+
 
   setColorLayout->addWidget ( initAnalogLabel1, 0,0);
   setColorLayout->addWidget ( m_checkBoxCbac ,0,1);
@@ -867,6 +906,8 @@ void KNutPrefDlg::initAnalog () {
   setColorLayout->addWidget ( m_AScaleButton ,7,1);
   setColorLayout->addWidget ( m_analogFontColorLabel, 8,0);
   setColorLayout->addWidget ( m_AFontButton ,8,1);
+  setColorLayout->addWidget ( m_digitalProcessingLabel, 9,0);
+  setColorLayout->addWidget ( m_digitalProcesingOfPointers, 9,1);
 
 
   m_checkBoxCbac->setChecked(m_prefData->customBAnalogColor);
@@ -893,10 +934,20 @@ void KNutPrefDlg::initAnalog () {
   m_analogScaleColorLabel->setEnabled(m_prefData->customOAnalogColor);
   m_analogFontColorLabel->setEnabled(m_prefData->customOAnalogColor);
 
+
+  m_digitalProcesingOfPointers->insertItem(i18n("Nothing processing"));
+  m_digitalProcesingOfPointers->insertItem(i18n("Fast antialiasing"));
+  m_digitalProcesingOfPointers->insertItem(i18n("Fine antialiasing"));
+  m_digitalProcesingOfPointers->insertItem(i18n("Fast antialiasing and blur motion"));
+  m_digitalProcesingOfPointers->insertItem(i18n("Fine antialiasing and blur motion"));
+
+  m_digitalProcesingOfPointers->setCurrentItem(m_prefData->typeDigitalProcessing);
+
+
   connect (m_checkBoxCbac,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBAnalogColor(bool)));
   connect (m_checkBoxCoac,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomOAnalogColor(bool)));
   }
-  
-  
-  
+
+
+
 #include "knutprefdlg.moc"
